# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['RequestLogProfileArgs', 'RequestLogProfile']

@pulumi.input_type
class RequestLogProfileArgs:
    def __init__(__self__, *,
                 name: pulumi.Input[str],
                 defaults_from: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 proxy_response: Optional[pulumi.Input[str]] = None,
                 proxyclose_on_error: Optional[pulumi.Input[str]] = None,
                 proxyrespond_on_loggingerror: Optional[pulumi.Input[str]] = None,
                 request_logging: Optional[pulumi.Input[str]] = None,
                 requestlog_error_pool: Optional[pulumi.Input[str]] = None,
                 requestlog_error_protocol: Optional[pulumi.Input[str]] = None,
                 requestlog_error_template: Optional[pulumi.Input[str]] = None,
                 requestlog_pool: Optional[pulumi.Input[str]] = None,
                 requestlog_protocol: Optional[pulumi.Input[str]] = None,
                 requestlog_template: Optional[pulumi.Input[str]] = None,
                 response_logging: Optional[pulumi.Input[str]] = None,
                 responselog_error_pool: Optional[pulumi.Input[str]] = None,
                 responselog_error_protocol: Optional[pulumi.Input[str]] = None,
                 responselog_error_template: Optional[pulumi.Input[str]] = None,
                 responselog_pool: Optional[pulumi.Input[str]] = None,
                 responselog_protocol: Optional[pulumi.Input[str]] = None,
                 responselog_template: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a RequestLogProfile resource.
        :param pulumi.Input[str] name: Name of the Request Logging profile,name of Profile should be full path. Full path is the combination of the `partition + profile name`,For example `/Common/request-log-profile-tc1`.
        :param pulumi.Input[str] defaults_from: Specifies the profile from which this profile inherits settings. The default is the system-supplied `request-log` profile.
        :param pulumi.Input[str] description: Specifies user-defined description.
        :param pulumi.Input[str] proxy_response: Defines the pool associated with logging request errors. The default is None.
        :param pulumi.Input[str] proxyclose_on_error: Defines the pool associated with logging request errors. The default is None.
        :param pulumi.Input[str] proxyrespond_on_loggingerror: Defines the pool associated with logging request errors. The default is None.
        :param pulumi.Input[str] request_logging: Enables or disables request logging. The default is `disabled`, possible values are `enabled` and `disabled`.
        :param pulumi.Input[str] requestlog_error_pool: Defines the pool associated with logging request errors. The default is None.
        :param pulumi.Input[str] requestlog_error_protocol: Specifies the protocol to be used for high-speed logging of request errors. The default is `mds-udp`,possible values are `mds-udp` and `mds-tcp`.
        :param pulumi.Input[str] requestlog_error_template: Specifies the directives and entries to be logged for request errors.
        :param pulumi.Input[str] requestlog_pool: Defines the pool to send logs to. Typically, the pool will contain one or more syslog servers. It is recommended that you create a pool specifically for logging requests. The default is `none`.
        :param pulumi.Input[str] requestlog_protocol: Specifies the protocol to be used for high-speed logging of requests. The default is `mds-udp`,possible values are `mds-udp` and `mds-tcp`.
        :param pulumi.Input[str] requestlog_template: Specifies the directives and entries to be logged. More infor on requestlog_template can be found [here](https://techdocs.f5.com/en-us/bigip-15-0-0/external-monitoring-of-big-ip-systems-implementations/configuring-request-logging.html). how to use can be find [here](https://my.f5.com/manage/s/article/K00847516).
        :param pulumi.Input[str] response_logging: Enables or disables response logging. The default is `disabled`, possible values are `enabled` and `disabled`.
        :param pulumi.Input[str] responselog_error_pool: Defines the pool associated with logging response errors. The default is `none`.
        :param pulumi.Input[str] responselog_error_protocol: Specifies the protocol to be used for high-speed logging of response errors. The default is `mds-udp`,possible values are `mds-udp` and `mds-tcp`.
        :param pulumi.Input[str] responselog_error_template: Specifies the directives and entries to be logged for request errors.
        :param pulumi.Input[str] responselog_pool: Defines the pool to send logs to. Typically, the pool contains one or more syslog servers. It is recommended that you create a pool specifically for logging responses. The default is `none`.
        :param pulumi.Input[str] responselog_protocol: Specifies the protocol to be used for high-speed logging of responses. The default is `mds-udp`,possible values are `mds-udp` and `mds-tcp`.
        :param pulumi.Input[str] responselog_template: Specifies the directives and entries to be logged. More infor on responselog_template can be found [here](https://techdocs.f5.com/en-us/bigip-15-0-0/external-monitoring-of-big-ip-systems-implementations/configuring-request-logging.html). how to use can be find [here](https://my.f5.com/manage/s/article/K00847516).
        """
        pulumi.set(__self__, "name", name)
        if defaults_from is not None:
            pulumi.set(__self__, "defaults_from", defaults_from)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if proxy_response is not None:
            pulumi.set(__self__, "proxy_response", proxy_response)
        if proxyclose_on_error is not None:
            pulumi.set(__self__, "proxyclose_on_error", proxyclose_on_error)
        if proxyrespond_on_loggingerror is not None:
            pulumi.set(__self__, "proxyrespond_on_loggingerror", proxyrespond_on_loggingerror)
        if request_logging is not None:
            pulumi.set(__self__, "request_logging", request_logging)
        if requestlog_error_pool is not None:
            pulumi.set(__self__, "requestlog_error_pool", requestlog_error_pool)
        if requestlog_error_protocol is not None:
            pulumi.set(__self__, "requestlog_error_protocol", requestlog_error_protocol)
        if requestlog_error_template is not None:
            pulumi.set(__self__, "requestlog_error_template", requestlog_error_template)
        if requestlog_pool is not None:
            pulumi.set(__self__, "requestlog_pool", requestlog_pool)
        if requestlog_protocol is not None:
            pulumi.set(__self__, "requestlog_protocol", requestlog_protocol)
        if requestlog_template is not None:
            pulumi.set(__self__, "requestlog_template", requestlog_template)
        if response_logging is not None:
            pulumi.set(__self__, "response_logging", response_logging)
        if responselog_error_pool is not None:
            pulumi.set(__self__, "responselog_error_pool", responselog_error_pool)
        if responselog_error_protocol is not None:
            pulumi.set(__self__, "responselog_error_protocol", responselog_error_protocol)
        if responselog_error_template is not None:
            pulumi.set(__self__, "responselog_error_template", responselog_error_template)
        if responselog_pool is not None:
            pulumi.set(__self__, "responselog_pool", responselog_pool)
        if responselog_protocol is not None:
            pulumi.set(__self__, "responselog_protocol", responselog_protocol)
        if responselog_template is not None:
            pulumi.set(__self__, "responselog_template", responselog_template)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        """
        Name of the Request Logging profile,name of Profile should be full path. Full path is the combination of the `partition + profile name`,For example `/Common/request-log-profile-tc1`.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="defaultsFrom")
    def defaults_from(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the profile from which this profile inherits settings. The default is the system-supplied `request-log` profile.
        """
        return pulumi.get(self, "defaults_from")

    @defaults_from.setter
    def defaults_from(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "defaults_from", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies user-defined description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="proxyResponse")
    def proxy_response(self) -> Optional[pulumi.Input[str]]:
        """
        Defines the pool associated with logging request errors. The default is None.
        """
        return pulumi.get(self, "proxy_response")

    @proxy_response.setter
    def proxy_response(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "proxy_response", value)

    @property
    @pulumi.getter(name="proxycloseOnError")
    def proxyclose_on_error(self) -> Optional[pulumi.Input[str]]:
        """
        Defines the pool associated with logging request errors. The default is None.
        """
        return pulumi.get(self, "proxyclose_on_error")

    @proxyclose_on_error.setter
    def proxyclose_on_error(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "proxyclose_on_error", value)

    @property
    @pulumi.getter(name="proxyrespondOnLoggingerror")
    def proxyrespond_on_loggingerror(self) -> Optional[pulumi.Input[str]]:
        """
        Defines the pool associated with logging request errors. The default is None.
        """
        return pulumi.get(self, "proxyrespond_on_loggingerror")

    @proxyrespond_on_loggingerror.setter
    def proxyrespond_on_loggingerror(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "proxyrespond_on_loggingerror", value)

    @property
    @pulumi.getter(name="requestLogging")
    def request_logging(self) -> Optional[pulumi.Input[str]]:
        """
        Enables or disables request logging. The default is `disabled`, possible values are `enabled` and `disabled`.
        """
        return pulumi.get(self, "request_logging")

    @request_logging.setter
    def request_logging(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "request_logging", value)

    @property
    @pulumi.getter(name="requestlogErrorPool")
    def requestlog_error_pool(self) -> Optional[pulumi.Input[str]]:
        """
        Defines the pool associated with logging request errors. The default is None.
        """
        return pulumi.get(self, "requestlog_error_pool")

    @requestlog_error_pool.setter
    def requestlog_error_pool(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "requestlog_error_pool", value)

    @property
    @pulumi.getter(name="requestlogErrorProtocol")
    def requestlog_error_protocol(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the protocol to be used for high-speed logging of request errors. The default is `mds-udp`,possible values are `mds-udp` and `mds-tcp`.
        """
        return pulumi.get(self, "requestlog_error_protocol")

    @requestlog_error_protocol.setter
    def requestlog_error_protocol(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "requestlog_error_protocol", value)

    @property
    @pulumi.getter(name="requestlogErrorTemplate")
    def requestlog_error_template(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the directives and entries to be logged for request errors.
        """
        return pulumi.get(self, "requestlog_error_template")

    @requestlog_error_template.setter
    def requestlog_error_template(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "requestlog_error_template", value)

    @property
    @pulumi.getter(name="requestlogPool")
    def requestlog_pool(self) -> Optional[pulumi.Input[str]]:
        """
        Defines the pool to send logs to. Typically, the pool will contain one or more syslog servers. It is recommended that you create a pool specifically for logging requests. The default is `none`.
        """
        return pulumi.get(self, "requestlog_pool")

    @requestlog_pool.setter
    def requestlog_pool(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "requestlog_pool", value)

    @property
    @pulumi.getter(name="requestlogProtocol")
    def requestlog_protocol(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the protocol to be used for high-speed logging of requests. The default is `mds-udp`,possible values are `mds-udp` and `mds-tcp`.
        """
        return pulumi.get(self, "requestlog_protocol")

    @requestlog_protocol.setter
    def requestlog_protocol(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "requestlog_protocol", value)

    @property
    @pulumi.getter(name="requestlogTemplate")
    def requestlog_template(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the directives and entries to be logged. More infor on requestlog_template can be found [here](https://techdocs.f5.com/en-us/bigip-15-0-0/external-monitoring-of-big-ip-systems-implementations/configuring-request-logging.html). how to use can be find [here](https://my.f5.com/manage/s/article/K00847516).
        """
        return pulumi.get(self, "requestlog_template")

    @requestlog_template.setter
    def requestlog_template(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "requestlog_template", value)

    @property
    @pulumi.getter(name="responseLogging")
    def response_logging(self) -> Optional[pulumi.Input[str]]:
        """
        Enables or disables response logging. The default is `disabled`, possible values are `enabled` and `disabled`.
        """
        return pulumi.get(self, "response_logging")

    @response_logging.setter
    def response_logging(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "response_logging", value)

    @property
    @pulumi.getter(name="responselogErrorPool")
    def responselog_error_pool(self) -> Optional[pulumi.Input[str]]:
        """
        Defines the pool associated with logging response errors. The default is `none`.
        """
        return pulumi.get(self, "responselog_error_pool")

    @responselog_error_pool.setter
    def responselog_error_pool(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "responselog_error_pool", value)

    @property
    @pulumi.getter(name="responselogErrorProtocol")
    def responselog_error_protocol(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the protocol to be used for high-speed logging of response errors. The default is `mds-udp`,possible values are `mds-udp` and `mds-tcp`.
        """
        return pulumi.get(self, "responselog_error_protocol")

    @responselog_error_protocol.setter
    def responselog_error_protocol(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "responselog_error_protocol", value)

    @property
    @pulumi.getter(name="responselogErrorTemplate")
    def responselog_error_template(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the directives and entries to be logged for request errors.
        """
        return pulumi.get(self, "responselog_error_template")

    @responselog_error_template.setter
    def responselog_error_template(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "responselog_error_template", value)

    @property
    @pulumi.getter(name="responselogPool")
    def responselog_pool(self) -> Optional[pulumi.Input[str]]:
        """
        Defines the pool to send logs to. Typically, the pool contains one or more syslog servers. It is recommended that you create a pool specifically for logging responses. The default is `none`.
        """
        return pulumi.get(self, "responselog_pool")

    @responselog_pool.setter
    def responselog_pool(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "responselog_pool", value)

    @property
    @pulumi.getter(name="responselogProtocol")
    def responselog_protocol(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the protocol to be used for high-speed logging of responses. The default is `mds-udp`,possible values are `mds-udp` and `mds-tcp`.
        """
        return pulumi.get(self, "responselog_protocol")

    @responselog_protocol.setter
    def responselog_protocol(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "responselog_protocol", value)

    @property
    @pulumi.getter(name="responselogTemplate")
    def responselog_template(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the directives and entries to be logged. More infor on responselog_template can be found [here](https://techdocs.f5.com/en-us/bigip-15-0-0/external-monitoring-of-big-ip-systems-implementations/configuring-request-logging.html). how to use can be find [here](https://my.f5.com/manage/s/article/K00847516).
        """
        return pulumi.get(self, "responselog_template")

    @responselog_template.setter
    def responselog_template(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "responselog_template", value)


@pulumi.input_type
class _RequestLogProfileState:
    def __init__(__self__, *,
                 defaults_from: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 proxy_response: Optional[pulumi.Input[str]] = None,
                 proxyclose_on_error: Optional[pulumi.Input[str]] = None,
                 proxyrespond_on_loggingerror: Optional[pulumi.Input[str]] = None,
                 request_logging: Optional[pulumi.Input[str]] = None,
                 requestlog_error_pool: Optional[pulumi.Input[str]] = None,
                 requestlog_error_protocol: Optional[pulumi.Input[str]] = None,
                 requestlog_error_template: Optional[pulumi.Input[str]] = None,
                 requestlog_pool: Optional[pulumi.Input[str]] = None,
                 requestlog_protocol: Optional[pulumi.Input[str]] = None,
                 requestlog_template: Optional[pulumi.Input[str]] = None,
                 response_logging: Optional[pulumi.Input[str]] = None,
                 responselog_error_pool: Optional[pulumi.Input[str]] = None,
                 responselog_error_protocol: Optional[pulumi.Input[str]] = None,
                 responselog_error_template: Optional[pulumi.Input[str]] = None,
                 responselog_pool: Optional[pulumi.Input[str]] = None,
                 responselog_protocol: Optional[pulumi.Input[str]] = None,
                 responselog_template: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering RequestLogProfile resources.
        :param pulumi.Input[str] defaults_from: Specifies the profile from which this profile inherits settings. The default is the system-supplied `request-log` profile.
        :param pulumi.Input[str] description: Specifies user-defined description.
        :param pulumi.Input[str] name: Name of the Request Logging profile,name of Profile should be full path. Full path is the combination of the `partition + profile name`,For example `/Common/request-log-profile-tc1`.
        :param pulumi.Input[str] proxy_response: Defines the pool associated with logging request errors. The default is None.
        :param pulumi.Input[str] proxyclose_on_error: Defines the pool associated with logging request errors. The default is None.
        :param pulumi.Input[str] proxyrespond_on_loggingerror: Defines the pool associated with logging request errors. The default is None.
        :param pulumi.Input[str] request_logging: Enables or disables request logging. The default is `disabled`, possible values are `enabled` and `disabled`.
        :param pulumi.Input[str] requestlog_error_pool: Defines the pool associated with logging request errors. The default is None.
        :param pulumi.Input[str] requestlog_error_protocol: Specifies the protocol to be used for high-speed logging of request errors. The default is `mds-udp`,possible values are `mds-udp` and `mds-tcp`.
        :param pulumi.Input[str] requestlog_error_template: Specifies the directives and entries to be logged for request errors.
        :param pulumi.Input[str] requestlog_pool: Defines the pool to send logs to. Typically, the pool will contain one or more syslog servers. It is recommended that you create a pool specifically for logging requests. The default is `none`.
        :param pulumi.Input[str] requestlog_protocol: Specifies the protocol to be used for high-speed logging of requests. The default is `mds-udp`,possible values are `mds-udp` and `mds-tcp`.
        :param pulumi.Input[str] requestlog_template: Specifies the directives and entries to be logged. More infor on requestlog_template can be found [here](https://techdocs.f5.com/en-us/bigip-15-0-0/external-monitoring-of-big-ip-systems-implementations/configuring-request-logging.html). how to use can be find [here](https://my.f5.com/manage/s/article/K00847516).
        :param pulumi.Input[str] response_logging: Enables or disables response logging. The default is `disabled`, possible values are `enabled` and `disabled`.
        :param pulumi.Input[str] responselog_error_pool: Defines the pool associated with logging response errors. The default is `none`.
        :param pulumi.Input[str] responselog_error_protocol: Specifies the protocol to be used for high-speed logging of response errors. The default is `mds-udp`,possible values are `mds-udp` and `mds-tcp`.
        :param pulumi.Input[str] responselog_error_template: Specifies the directives and entries to be logged for request errors.
        :param pulumi.Input[str] responselog_pool: Defines the pool to send logs to. Typically, the pool contains one or more syslog servers. It is recommended that you create a pool specifically for logging responses. The default is `none`.
        :param pulumi.Input[str] responselog_protocol: Specifies the protocol to be used for high-speed logging of responses. The default is `mds-udp`,possible values are `mds-udp` and `mds-tcp`.
        :param pulumi.Input[str] responselog_template: Specifies the directives and entries to be logged. More infor on responselog_template can be found [here](https://techdocs.f5.com/en-us/bigip-15-0-0/external-monitoring-of-big-ip-systems-implementations/configuring-request-logging.html). how to use can be find [here](https://my.f5.com/manage/s/article/K00847516).
        """
        if defaults_from is not None:
            pulumi.set(__self__, "defaults_from", defaults_from)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if proxy_response is not None:
            pulumi.set(__self__, "proxy_response", proxy_response)
        if proxyclose_on_error is not None:
            pulumi.set(__self__, "proxyclose_on_error", proxyclose_on_error)
        if proxyrespond_on_loggingerror is not None:
            pulumi.set(__self__, "proxyrespond_on_loggingerror", proxyrespond_on_loggingerror)
        if request_logging is not None:
            pulumi.set(__self__, "request_logging", request_logging)
        if requestlog_error_pool is not None:
            pulumi.set(__self__, "requestlog_error_pool", requestlog_error_pool)
        if requestlog_error_protocol is not None:
            pulumi.set(__self__, "requestlog_error_protocol", requestlog_error_protocol)
        if requestlog_error_template is not None:
            pulumi.set(__self__, "requestlog_error_template", requestlog_error_template)
        if requestlog_pool is not None:
            pulumi.set(__self__, "requestlog_pool", requestlog_pool)
        if requestlog_protocol is not None:
            pulumi.set(__self__, "requestlog_protocol", requestlog_protocol)
        if requestlog_template is not None:
            pulumi.set(__self__, "requestlog_template", requestlog_template)
        if response_logging is not None:
            pulumi.set(__self__, "response_logging", response_logging)
        if responselog_error_pool is not None:
            pulumi.set(__self__, "responselog_error_pool", responselog_error_pool)
        if responselog_error_protocol is not None:
            pulumi.set(__self__, "responselog_error_protocol", responselog_error_protocol)
        if responselog_error_template is not None:
            pulumi.set(__self__, "responselog_error_template", responselog_error_template)
        if responselog_pool is not None:
            pulumi.set(__self__, "responselog_pool", responselog_pool)
        if responselog_protocol is not None:
            pulumi.set(__self__, "responselog_protocol", responselog_protocol)
        if responselog_template is not None:
            pulumi.set(__self__, "responselog_template", responselog_template)

    @property
    @pulumi.getter(name="defaultsFrom")
    def defaults_from(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the profile from which this profile inherits settings. The default is the system-supplied `request-log` profile.
        """
        return pulumi.get(self, "defaults_from")

    @defaults_from.setter
    def defaults_from(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "defaults_from", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies user-defined description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the Request Logging profile,name of Profile should be full path. Full path is the combination of the `partition + profile name`,For example `/Common/request-log-profile-tc1`.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="proxyResponse")
    def proxy_response(self) -> Optional[pulumi.Input[str]]:
        """
        Defines the pool associated with logging request errors. The default is None.
        """
        return pulumi.get(self, "proxy_response")

    @proxy_response.setter
    def proxy_response(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "proxy_response", value)

    @property
    @pulumi.getter(name="proxycloseOnError")
    def proxyclose_on_error(self) -> Optional[pulumi.Input[str]]:
        """
        Defines the pool associated with logging request errors. The default is None.
        """
        return pulumi.get(self, "proxyclose_on_error")

    @proxyclose_on_error.setter
    def proxyclose_on_error(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "proxyclose_on_error", value)

    @property
    @pulumi.getter(name="proxyrespondOnLoggingerror")
    def proxyrespond_on_loggingerror(self) -> Optional[pulumi.Input[str]]:
        """
        Defines the pool associated with logging request errors. The default is None.
        """
        return pulumi.get(self, "proxyrespond_on_loggingerror")

    @proxyrespond_on_loggingerror.setter
    def proxyrespond_on_loggingerror(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "proxyrespond_on_loggingerror", value)

    @property
    @pulumi.getter(name="requestLogging")
    def request_logging(self) -> Optional[pulumi.Input[str]]:
        """
        Enables or disables request logging. The default is `disabled`, possible values are `enabled` and `disabled`.
        """
        return pulumi.get(self, "request_logging")

    @request_logging.setter
    def request_logging(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "request_logging", value)

    @property
    @pulumi.getter(name="requestlogErrorPool")
    def requestlog_error_pool(self) -> Optional[pulumi.Input[str]]:
        """
        Defines the pool associated with logging request errors. The default is None.
        """
        return pulumi.get(self, "requestlog_error_pool")

    @requestlog_error_pool.setter
    def requestlog_error_pool(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "requestlog_error_pool", value)

    @property
    @pulumi.getter(name="requestlogErrorProtocol")
    def requestlog_error_protocol(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the protocol to be used for high-speed logging of request errors. The default is `mds-udp`,possible values are `mds-udp` and `mds-tcp`.
        """
        return pulumi.get(self, "requestlog_error_protocol")

    @requestlog_error_protocol.setter
    def requestlog_error_protocol(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "requestlog_error_protocol", value)

    @property
    @pulumi.getter(name="requestlogErrorTemplate")
    def requestlog_error_template(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the directives and entries to be logged for request errors.
        """
        return pulumi.get(self, "requestlog_error_template")

    @requestlog_error_template.setter
    def requestlog_error_template(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "requestlog_error_template", value)

    @property
    @pulumi.getter(name="requestlogPool")
    def requestlog_pool(self) -> Optional[pulumi.Input[str]]:
        """
        Defines the pool to send logs to. Typically, the pool will contain one or more syslog servers. It is recommended that you create a pool specifically for logging requests. The default is `none`.
        """
        return pulumi.get(self, "requestlog_pool")

    @requestlog_pool.setter
    def requestlog_pool(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "requestlog_pool", value)

    @property
    @pulumi.getter(name="requestlogProtocol")
    def requestlog_protocol(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the protocol to be used for high-speed logging of requests. The default is `mds-udp`,possible values are `mds-udp` and `mds-tcp`.
        """
        return pulumi.get(self, "requestlog_protocol")

    @requestlog_protocol.setter
    def requestlog_protocol(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "requestlog_protocol", value)

    @property
    @pulumi.getter(name="requestlogTemplate")
    def requestlog_template(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the directives and entries to be logged. More infor on requestlog_template can be found [here](https://techdocs.f5.com/en-us/bigip-15-0-0/external-monitoring-of-big-ip-systems-implementations/configuring-request-logging.html). how to use can be find [here](https://my.f5.com/manage/s/article/K00847516).
        """
        return pulumi.get(self, "requestlog_template")

    @requestlog_template.setter
    def requestlog_template(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "requestlog_template", value)

    @property
    @pulumi.getter(name="responseLogging")
    def response_logging(self) -> Optional[pulumi.Input[str]]:
        """
        Enables or disables response logging. The default is `disabled`, possible values are `enabled` and `disabled`.
        """
        return pulumi.get(self, "response_logging")

    @response_logging.setter
    def response_logging(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "response_logging", value)

    @property
    @pulumi.getter(name="responselogErrorPool")
    def responselog_error_pool(self) -> Optional[pulumi.Input[str]]:
        """
        Defines the pool associated with logging response errors. The default is `none`.
        """
        return pulumi.get(self, "responselog_error_pool")

    @responselog_error_pool.setter
    def responselog_error_pool(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "responselog_error_pool", value)

    @property
    @pulumi.getter(name="responselogErrorProtocol")
    def responselog_error_protocol(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the protocol to be used for high-speed logging of response errors. The default is `mds-udp`,possible values are `mds-udp` and `mds-tcp`.
        """
        return pulumi.get(self, "responselog_error_protocol")

    @responselog_error_protocol.setter
    def responselog_error_protocol(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "responselog_error_protocol", value)

    @property
    @pulumi.getter(name="responselogErrorTemplate")
    def responselog_error_template(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the directives and entries to be logged for request errors.
        """
        return pulumi.get(self, "responselog_error_template")

    @responselog_error_template.setter
    def responselog_error_template(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "responselog_error_template", value)

    @property
    @pulumi.getter(name="responselogPool")
    def responselog_pool(self) -> Optional[pulumi.Input[str]]:
        """
        Defines the pool to send logs to. Typically, the pool contains one or more syslog servers. It is recommended that you create a pool specifically for logging responses. The default is `none`.
        """
        return pulumi.get(self, "responselog_pool")

    @responselog_pool.setter
    def responselog_pool(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "responselog_pool", value)

    @property
    @pulumi.getter(name="responselogProtocol")
    def responselog_protocol(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the protocol to be used for high-speed logging of responses. The default is `mds-udp`,possible values are `mds-udp` and `mds-tcp`.
        """
        return pulumi.get(self, "responselog_protocol")

    @responselog_protocol.setter
    def responselog_protocol(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "responselog_protocol", value)

    @property
    @pulumi.getter(name="responselogTemplate")
    def responselog_template(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the directives and entries to be logged. More infor on responselog_template can be found [here](https://techdocs.f5.com/en-us/bigip-15-0-0/external-monitoring-of-big-ip-systems-implementations/configuring-request-logging.html). how to use can be find [here](https://my.f5.com/manage/s/article/K00847516).
        """
        return pulumi.get(self, "responselog_template")

    @responselog_template.setter
    def responselog_template(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "responselog_template", value)


class RequestLogProfile(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 defaults_from: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 proxy_response: Optional[pulumi.Input[str]] = None,
                 proxyclose_on_error: Optional[pulumi.Input[str]] = None,
                 proxyrespond_on_loggingerror: Optional[pulumi.Input[str]] = None,
                 request_logging: Optional[pulumi.Input[str]] = None,
                 requestlog_error_pool: Optional[pulumi.Input[str]] = None,
                 requestlog_error_protocol: Optional[pulumi.Input[str]] = None,
                 requestlog_error_template: Optional[pulumi.Input[str]] = None,
                 requestlog_pool: Optional[pulumi.Input[str]] = None,
                 requestlog_protocol: Optional[pulumi.Input[str]] = None,
                 requestlog_template: Optional[pulumi.Input[str]] = None,
                 response_logging: Optional[pulumi.Input[str]] = None,
                 responselog_error_pool: Optional[pulumi.Input[str]] = None,
                 responselog_error_protocol: Optional[pulumi.Input[str]] = None,
                 responselog_error_template: Optional[pulumi.Input[str]] = None,
                 responselog_pool: Optional[pulumi.Input[str]] = None,
                 responselog_protocol: Optional[pulumi.Input[str]] = None,
                 responselog_template: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        `ltm.RequestLogProfile` Resource used for Configures request logging using the Request Logging profile

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        request_log_profile_tc1_child = f5bigip.ltm.RequestLogProfile("request-log-profile-tc1-child",
            name="/Common/request-log-profile-tc1-child",
            defaults_from=request_log_profile_tc1["name"],
            request_logging="disabled",
            requestlog_pool="/Common/pool2",
            requestlog_error_pool="/Common/pool1",
            requestlog_protocol="mds-tcp",
            requestlog_error_protocol="mds-tcp",
            responselog_protocol="mds-tcp",
            responselog_error_protocol="mds-tcp")
        ```

        ## Import

        BIG-IP LTM Request Log profiles can be imported using the `name`, e.g.

        bash

        ```sh
        $ pulumi import f5bigip:ltm/requestLogProfile:RequestLogProfile test-request-log /Common/test-request-log
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] defaults_from: Specifies the profile from which this profile inherits settings. The default is the system-supplied `request-log` profile.
        :param pulumi.Input[str] description: Specifies user-defined description.
        :param pulumi.Input[str] name: Name of the Request Logging profile,name of Profile should be full path. Full path is the combination of the `partition + profile name`,For example `/Common/request-log-profile-tc1`.
        :param pulumi.Input[str] proxy_response: Defines the pool associated with logging request errors. The default is None.
        :param pulumi.Input[str] proxyclose_on_error: Defines the pool associated with logging request errors. The default is None.
        :param pulumi.Input[str] proxyrespond_on_loggingerror: Defines the pool associated with logging request errors. The default is None.
        :param pulumi.Input[str] request_logging: Enables or disables request logging. The default is `disabled`, possible values are `enabled` and `disabled`.
        :param pulumi.Input[str] requestlog_error_pool: Defines the pool associated with logging request errors. The default is None.
        :param pulumi.Input[str] requestlog_error_protocol: Specifies the protocol to be used for high-speed logging of request errors. The default is `mds-udp`,possible values are `mds-udp` and `mds-tcp`.
        :param pulumi.Input[str] requestlog_error_template: Specifies the directives and entries to be logged for request errors.
        :param pulumi.Input[str] requestlog_pool: Defines the pool to send logs to. Typically, the pool will contain one or more syslog servers. It is recommended that you create a pool specifically for logging requests. The default is `none`.
        :param pulumi.Input[str] requestlog_protocol: Specifies the protocol to be used for high-speed logging of requests. The default is `mds-udp`,possible values are `mds-udp` and `mds-tcp`.
        :param pulumi.Input[str] requestlog_template: Specifies the directives and entries to be logged. More infor on requestlog_template can be found [here](https://techdocs.f5.com/en-us/bigip-15-0-0/external-monitoring-of-big-ip-systems-implementations/configuring-request-logging.html). how to use can be find [here](https://my.f5.com/manage/s/article/K00847516).
        :param pulumi.Input[str] response_logging: Enables or disables response logging. The default is `disabled`, possible values are `enabled` and `disabled`.
        :param pulumi.Input[str] responselog_error_pool: Defines the pool associated with logging response errors. The default is `none`.
        :param pulumi.Input[str] responselog_error_protocol: Specifies the protocol to be used for high-speed logging of response errors. The default is `mds-udp`,possible values are `mds-udp` and `mds-tcp`.
        :param pulumi.Input[str] responselog_error_template: Specifies the directives and entries to be logged for request errors.
        :param pulumi.Input[str] responselog_pool: Defines the pool to send logs to. Typically, the pool contains one or more syslog servers. It is recommended that you create a pool specifically for logging responses. The default is `none`.
        :param pulumi.Input[str] responselog_protocol: Specifies the protocol to be used for high-speed logging of responses. The default is `mds-udp`,possible values are `mds-udp` and `mds-tcp`.
        :param pulumi.Input[str] responselog_template: Specifies the directives and entries to be logged. More infor on responselog_template can be found [here](https://techdocs.f5.com/en-us/bigip-15-0-0/external-monitoring-of-big-ip-systems-implementations/configuring-request-logging.html). how to use can be find [here](https://my.f5.com/manage/s/article/K00847516).
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RequestLogProfileArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        `ltm.RequestLogProfile` Resource used for Configures request logging using the Request Logging profile

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        request_log_profile_tc1_child = f5bigip.ltm.RequestLogProfile("request-log-profile-tc1-child",
            name="/Common/request-log-profile-tc1-child",
            defaults_from=request_log_profile_tc1["name"],
            request_logging="disabled",
            requestlog_pool="/Common/pool2",
            requestlog_error_pool="/Common/pool1",
            requestlog_protocol="mds-tcp",
            requestlog_error_protocol="mds-tcp",
            responselog_protocol="mds-tcp",
            responselog_error_protocol="mds-tcp")
        ```

        ## Import

        BIG-IP LTM Request Log profiles can be imported using the `name`, e.g.

        bash

        ```sh
        $ pulumi import f5bigip:ltm/requestLogProfile:RequestLogProfile test-request-log /Common/test-request-log
        ```

        :param str resource_name: The name of the resource.
        :param RequestLogProfileArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RequestLogProfileArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 defaults_from: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 proxy_response: Optional[pulumi.Input[str]] = None,
                 proxyclose_on_error: Optional[pulumi.Input[str]] = None,
                 proxyrespond_on_loggingerror: Optional[pulumi.Input[str]] = None,
                 request_logging: Optional[pulumi.Input[str]] = None,
                 requestlog_error_pool: Optional[pulumi.Input[str]] = None,
                 requestlog_error_protocol: Optional[pulumi.Input[str]] = None,
                 requestlog_error_template: Optional[pulumi.Input[str]] = None,
                 requestlog_pool: Optional[pulumi.Input[str]] = None,
                 requestlog_protocol: Optional[pulumi.Input[str]] = None,
                 requestlog_template: Optional[pulumi.Input[str]] = None,
                 response_logging: Optional[pulumi.Input[str]] = None,
                 responselog_error_pool: Optional[pulumi.Input[str]] = None,
                 responselog_error_protocol: Optional[pulumi.Input[str]] = None,
                 responselog_error_template: Optional[pulumi.Input[str]] = None,
                 responselog_pool: Optional[pulumi.Input[str]] = None,
                 responselog_protocol: Optional[pulumi.Input[str]] = None,
                 responselog_template: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RequestLogProfileArgs.__new__(RequestLogProfileArgs)

            __props__.__dict__["defaults_from"] = defaults_from
            __props__.__dict__["description"] = description
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            __props__.__dict__["proxy_response"] = proxy_response
            __props__.__dict__["proxyclose_on_error"] = proxyclose_on_error
            __props__.__dict__["proxyrespond_on_loggingerror"] = proxyrespond_on_loggingerror
            __props__.__dict__["request_logging"] = request_logging
            __props__.__dict__["requestlog_error_pool"] = requestlog_error_pool
            __props__.__dict__["requestlog_error_protocol"] = requestlog_error_protocol
            __props__.__dict__["requestlog_error_template"] = requestlog_error_template
            __props__.__dict__["requestlog_pool"] = requestlog_pool
            __props__.__dict__["requestlog_protocol"] = requestlog_protocol
            __props__.__dict__["requestlog_template"] = requestlog_template
            __props__.__dict__["response_logging"] = response_logging
            __props__.__dict__["responselog_error_pool"] = responselog_error_pool
            __props__.__dict__["responselog_error_protocol"] = responselog_error_protocol
            __props__.__dict__["responselog_error_template"] = responselog_error_template
            __props__.__dict__["responselog_pool"] = responselog_pool
            __props__.__dict__["responselog_protocol"] = responselog_protocol
            __props__.__dict__["responselog_template"] = responselog_template
        super(RequestLogProfile, __self__).__init__(
            'f5bigip:ltm/requestLogProfile:RequestLogProfile',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            defaults_from: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            proxy_response: Optional[pulumi.Input[str]] = None,
            proxyclose_on_error: Optional[pulumi.Input[str]] = None,
            proxyrespond_on_loggingerror: Optional[pulumi.Input[str]] = None,
            request_logging: Optional[pulumi.Input[str]] = None,
            requestlog_error_pool: Optional[pulumi.Input[str]] = None,
            requestlog_error_protocol: Optional[pulumi.Input[str]] = None,
            requestlog_error_template: Optional[pulumi.Input[str]] = None,
            requestlog_pool: Optional[pulumi.Input[str]] = None,
            requestlog_protocol: Optional[pulumi.Input[str]] = None,
            requestlog_template: Optional[pulumi.Input[str]] = None,
            response_logging: Optional[pulumi.Input[str]] = None,
            responselog_error_pool: Optional[pulumi.Input[str]] = None,
            responselog_error_protocol: Optional[pulumi.Input[str]] = None,
            responselog_error_template: Optional[pulumi.Input[str]] = None,
            responselog_pool: Optional[pulumi.Input[str]] = None,
            responselog_protocol: Optional[pulumi.Input[str]] = None,
            responselog_template: Optional[pulumi.Input[str]] = None) -> 'RequestLogProfile':
        """
        Get an existing RequestLogProfile resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] defaults_from: Specifies the profile from which this profile inherits settings. The default is the system-supplied `request-log` profile.
        :param pulumi.Input[str] description: Specifies user-defined description.
        :param pulumi.Input[str] name: Name of the Request Logging profile,name of Profile should be full path. Full path is the combination of the `partition + profile name`,For example `/Common/request-log-profile-tc1`.
        :param pulumi.Input[str] proxy_response: Defines the pool associated with logging request errors. The default is None.
        :param pulumi.Input[str] proxyclose_on_error: Defines the pool associated with logging request errors. The default is None.
        :param pulumi.Input[str] proxyrespond_on_loggingerror: Defines the pool associated with logging request errors. The default is None.
        :param pulumi.Input[str] request_logging: Enables or disables request logging. The default is `disabled`, possible values are `enabled` and `disabled`.
        :param pulumi.Input[str] requestlog_error_pool: Defines the pool associated with logging request errors. The default is None.
        :param pulumi.Input[str] requestlog_error_protocol: Specifies the protocol to be used for high-speed logging of request errors. The default is `mds-udp`,possible values are `mds-udp` and `mds-tcp`.
        :param pulumi.Input[str] requestlog_error_template: Specifies the directives and entries to be logged for request errors.
        :param pulumi.Input[str] requestlog_pool: Defines the pool to send logs to. Typically, the pool will contain one or more syslog servers. It is recommended that you create a pool specifically for logging requests. The default is `none`.
        :param pulumi.Input[str] requestlog_protocol: Specifies the protocol to be used for high-speed logging of requests. The default is `mds-udp`,possible values are `mds-udp` and `mds-tcp`.
        :param pulumi.Input[str] requestlog_template: Specifies the directives and entries to be logged. More infor on requestlog_template can be found [here](https://techdocs.f5.com/en-us/bigip-15-0-0/external-monitoring-of-big-ip-systems-implementations/configuring-request-logging.html). how to use can be find [here](https://my.f5.com/manage/s/article/K00847516).
        :param pulumi.Input[str] response_logging: Enables or disables response logging. The default is `disabled`, possible values are `enabled` and `disabled`.
        :param pulumi.Input[str] responselog_error_pool: Defines the pool associated with logging response errors. The default is `none`.
        :param pulumi.Input[str] responselog_error_protocol: Specifies the protocol to be used for high-speed logging of response errors. The default is `mds-udp`,possible values are `mds-udp` and `mds-tcp`.
        :param pulumi.Input[str] responselog_error_template: Specifies the directives and entries to be logged for request errors.
        :param pulumi.Input[str] responselog_pool: Defines the pool to send logs to. Typically, the pool contains one or more syslog servers. It is recommended that you create a pool specifically for logging responses. The default is `none`.
        :param pulumi.Input[str] responselog_protocol: Specifies the protocol to be used for high-speed logging of responses. The default is `mds-udp`,possible values are `mds-udp` and `mds-tcp`.
        :param pulumi.Input[str] responselog_template: Specifies the directives and entries to be logged. More infor on responselog_template can be found [here](https://techdocs.f5.com/en-us/bigip-15-0-0/external-monitoring-of-big-ip-systems-implementations/configuring-request-logging.html). how to use can be find [here](https://my.f5.com/manage/s/article/K00847516).
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RequestLogProfileState.__new__(_RequestLogProfileState)

        __props__.__dict__["defaults_from"] = defaults_from
        __props__.__dict__["description"] = description
        __props__.__dict__["name"] = name
        __props__.__dict__["proxy_response"] = proxy_response
        __props__.__dict__["proxyclose_on_error"] = proxyclose_on_error
        __props__.__dict__["proxyrespond_on_loggingerror"] = proxyrespond_on_loggingerror
        __props__.__dict__["request_logging"] = request_logging
        __props__.__dict__["requestlog_error_pool"] = requestlog_error_pool
        __props__.__dict__["requestlog_error_protocol"] = requestlog_error_protocol
        __props__.__dict__["requestlog_error_template"] = requestlog_error_template
        __props__.__dict__["requestlog_pool"] = requestlog_pool
        __props__.__dict__["requestlog_protocol"] = requestlog_protocol
        __props__.__dict__["requestlog_template"] = requestlog_template
        __props__.__dict__["response_logging"] = response_logging
        __props__.__dict__["responselog_error_pool"] = responselog_error_pool
        __props__.__dict__["responselog_error_protocol"] = responselog_error_protocol
        __props__.__dict__["responselog_error_template"] = responselog_error_template
        __props__.__dict__["responselog_pool"] = responselog_pool
        __props__.__dict__["responselog_protocol"] = responselog_protocol
        __props__.__dict__["responselog_template"] = responselog_template
        return RequestLogProfile(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="defaultsFrom")
    def defaults_from(self) -> pulumi.Output[Optional[str]]:
        """
        Specifies the profile from which this profile inherits settings. The default is the system-supplied `request-log` profile.
        """
        return pulumi.get(self, "defaults_from")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[str]:
        """
        Specifies user-defined description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of the Request Logging profile,name of Profile should be full path. Full path is the combination of the `partition + profile name`,For example `/Common/request-log-profile-tc1`.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="proxyResponse")
    def proxy_response(self) -> pulumi.Output[Optional[str]]:
        """
        Defines the pool associated with logging request errors. The default is None.
        """
        return pulumi.get(self, "proxy_response")

    @property
    @pulumi.getter(name="proxycloseOnError")
    def proxyclose_on_error(self) -> pulumi.Output[Optional[str]]:
        """
        Defines the pool associated with logging request errors. The default is None.
        """
        return pulumi.get(self, "proxyclose_on_error")

    @property
    @pulumi.getter(name="proxyrespondOnLoggingerror")
    def proxyrespond_on_loggingerror(self) -> pulumi.Output[Optional[str]]:
        """
        Defines the pool associated with logging request errors. The default is None.
        """
        return pulumi.get(self, "proxyrespond_on_loggingerror")

    @property
    @pulumi.getter(name="requestLogging")
    def request_logging(self) -> pulumi.Output[str]:
        """
        Enables or disables request logging. The default is `disabled`, possible values are `enabled` and `disabled`.
        """
        return pulumi.get(self, "request_logging")

    @property
    @pulumi.getter(name="requestlogErrorPool")
    def requestlog_error_pool(self) -> pulumi.Output[Optional[str]]:
        """
        Defines the pool associated with logging request errors. The default is None.
        """
        return pulumi.get(self, "requestlog_error_pool")

    @property
    @pulumi.getter(name="requestlogErrorProtocol")
    def requestlog_error_protocol(self) -> pulumi.Output[Optional[str]]:
        """
        Specifies the protocol to be used for high-speed logging of request errors. The default is `mds-udp`,possible values are `mds-udp` and `mds-tcp`.
        """
        return pulumi.get(self, "requestlog_error_protocol")

    @property
    @pulumi.getter(name="requestlogErrorTemplate")
    def requestlog_error_template(self) -> pulumi.Output[Optional[str]]:
        """
        Specifies the directives and entries to be logged for request errors.
        """
        return pulumi.get(self, "requestlog_error_template")

    @property
    @pulumi.getter(name="requestlogPool")
    def requestlog_pool(self) -> pulumi.Output[Optional[str]]:
        """
        Defines the pool to send logs to. Typically, the pool will contain one or more syslog servers. It is recommended that you create a pool specifically for logging requests. The default is `none`.
        """
        return pulumi.get(self, "requestlog_pool")

    @property
    @pulumi.getter(name="requestlogProtocol")
    def requestlog_protocol(self) -> pulumi.Output[Optional[str]]:
        """
        Specifies the protocol to be used for high-speed logging of requests. The default is `mds-udp`,possible values are `mds-udp` and `mds-tcp`.
        """
        return pulumi.get(self, "requestlog_protocol")

    @property
    @pulumi.getter(name="requestlogTemplate")
    def requestlog_template(self) -> pulumi.Output[Optional[str]]:
        """
        Specifies the directives and entries to be logged. More infor on requestlog_template can be found [here](https://techdocs.f5.com/en-us/bigip-15-0-0/external-monitoring-of-big-ip-systems-implementations/configuring-request-logging.html). how to use can be find [here](https://my.f5.com/manage/s/article/K00847516).
        """
        return pulumi.get(self, "requestlog_template")

    @property
    @pulumi.getter(name="responseLogging")
    def response_logging(self) -> pulumi.Output[str]:
        """
        Enables or disables response logging. The default is `disabled`, possible values are `enabled` and `disabled`.
        """
        return pulumi.get(self, "response_logging")

    @property
    @pulumi.getter(name="responselogErrorPool")
    def responselog_error_pool(self) -> pulumi.Output[Optional[str]]:
        """
        Defines the pool associated with logging response errors. The default is `none`.
        """
        return pulumi.get(self, "responselog_error_pool")

    @property
    @pulumi.getter(name="responselogErrorProtocol")
    def responselog_error_protocol(self) -> pulumi.Output[Optional[str]]:
        """
        Specifies the protocol to be used for high-speed logging of response errors. The default is `mds-udp`,possible values are `mds-udp` and `mds-tcp`.
        """
        return pulumi.get(self, "responselog_error_protocol")

    @property
    @pulumi.getter(name="responselogErrorTemplate")
    def responselog_error_template(self) -> pulumi.Output[Optional[str]]:
        """
        Specifies the directives and entries to be logged for request errors.
        """
        return pulumi.get(self, "responselog_error_template")

    @property
    @pulumi.getter(name="responselogPool")
    def responselog_pool(self) -> pulumi.Output[Optional[str]]:
        """
        Defines the pool to send logs to. Typically, the pool contains one or more syslog servers. It is recommended that you create a pool specifically for logging responses. The default is `none`.
        """
        return pulumi.get(self, "responselog_pool")

    @property
    @pulumi.getter(name="responselogProtocol")
    def responselog_protocol(self) -> pulumi.Output[Optional[str]]:
        """
        Specifies the protocol to be used for high-speed logging of responses. The default is `mds-udp`,possible values are `mds-udp` and `mds-tcp`.
        """
        return pulumi.get(self, "responselog_protocol")

    @property
    @pulumi.getter(name="responselogTemplate")
    def responselog_template(self) -> pulumi.Output[Optional[str]]:
        """
        Specifies the directives and entries to be logged. More infor on responselog_template can be found [here](https://techdocs.f5.com/en-us/bigip-15-0-0/external-monitoring-of-big-ip-systems-implementations/configuring-request-logging.html). how to use can be find [here](https://my.f5.com/manage/s/article/K00847516).
        """
        return pulumi.get(self, "responselog_template")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['KeyArgs', 'Key']

@pulumi.input_type
class KeyArgs:
    def __init__(__self__, *,
                 content: pulumi.Input[str],
                 name: pulumi.Input[str],
                 full_path: Optional[pulumi.Input[str]] = None,
                 partition: Optional[pulumi.Input[str]] = None,
                 passphrase: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Key resource.
        :param pulumi.Input[str] content: Content of SSL certificate key present on local Disk
        :param pulumi.Input[str] name: Name of the SSL Certificate key to be Imported on to BIGIP
        :param pulumi.Input[str] full_path: Full Path Name of ssl key
        :param pulumi.Input[str] partition: Partition of ssl certificate key
        :param pulumi.Input[str] passphrase: Passphrase on key.
        """
        pulumi.set(__self__, "content", content)
        pulumi.set(__self__, "name", name)
        if full_path is not None:
            pulumi.set(__self__, "full_path", full_path)
        if partition is not None:
            pulumi.set(__self__, "partition", partition)
        if passphrase is not None:
            pulumi.set(__self__, "passphrase", passphrase)

    @property
    @pulumi.getter
    def content(self) -> pulumi.Input[str]:
        """
        Content of SSL certificate key present on local Disk
        """
        return pulumi.get(self, "content")

    @content.setter
    def content(self, value: pulumi.Input[str]):
        pulumi.set(self, "content", value)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        """
        Name of the SSL Certificate key to be Imported on to BIGIP
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="fullPath")
    def full_path(self) -> Optional[pulumi.Input[str]]:
        """
        Full Path Name of ssl key
        """
        return pulumi.get(self, "full_path")

    @full_path.setter
    def full_path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "full_path", value)

    @property
    @pulumi.getter
    def partition(self) -> Optional[pulumi.Input[str]]:
        """
        Partition of ssl certificate key
        """
        return pulumi.get(self, "partition")

    @partition.setter
    def partition(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "partition", value)

    @property
    @pulumi.getter
    def passphrase(self) -> Optional[pulumi.Input[str]]:
        """
        Passphrase on key.
        """
        return pulumi.get(self, "passphrase")

    @passphrase.setter
    def passphrase(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "passphrase", value)


@pulumi.input_type
class _KeyState:
    def __init__(__self__, *,
                 content: Optional[pulumi.Input[str]] = None,
                 full_path: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 partition: Optional[pulumi.Input[str]] = None,
                 passphrase: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Key resources.
        :param pulumi.Input[str] content: Content of SSL certificate key present on local Disk
        :param pulumi.Input[str] full_path: Full Path Name of ssl key
        :param pulumi.Input[str] name: Name of the SSL Certificate key to be Imported on to BIGIP
        :param pulumi.Input[str] partition: Partition of ssl certificate key
        :param pulumi.Input[str] passphrase: Passphrase on key.
        """
        if content is not None:
            pulumi.set(__self__, "content", content)
        if full_path is not None:
            pulumi.set(__self__, "full_path", full_path)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if partition is not None:
            pulumi.set(__self__, "partition", partition)
        if passphrase is not None:
            pulumi.set(__self__, "passphrase", passphrase)

    @property
    @pulumi.getter
    def content(self) -> Optional[pulumi.Input[str]]:
        """
        Content of SSL certificate key present on local Disk
        """
        return pulumi.get(self, "content")

    @content.setter
    def content(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "content", value)

    @property
    @pulumi.getter(name="fullPath")
    def full_path(self) -> Optional[pulumi.Input[str]]:
        """
        Full Path Name of ssl key
        """
        return pulumi.get(self, "full_path")

    @full_path.setter
    def full_path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "full_path", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the SSL Certificate key to be Imported on to BIGIP
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def partition(self) -> Optional[pulumi.Input[str]]:
        """
        Partition of ssl certificate key
        """
        return pulumi.get(self, "partition")

    @partition.setter
    def partition(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "partition", value)

    @property
    @pulumi.getter
    def passphrase(self) -> Optional[pulumi.Input[str]]:
        """
        Passphrase on key.
        """
        return pulumi.get(self, "passphrase")

    @passphrase.setter
    def passphrase(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "passphrase", value)


class Key(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 content: Optional[pulumi.Input[str]] = None,
                 full_path: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 partition: Optional[pulumi.Input[str]] = None,
                 passphrase: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        `ssl.Key` This resource will import SSL certificate key on BIG-IP LTM.
        Certificate key can be imported from certificate key files on the local disk, in PEM format

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip
        import pulumi_std as std

        test_key = f5bigip.ssl.Key("test-key",
            name="serverkey.key",
            content=std.file(input="serverkey.key").result,
            partition="Common")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] content: Content of SSL certificate key present on local Disk
        :param pulumi.Input[str] full_path: Full Path Name of ssl key
        :param pulumi.Input[str] name: Name of the SSL Certificate key to be Imported on to BIGIP
        :param pulumi.Input[str] partition: Partition of ssl certificate key
        :param pulumi.Input[str] passphrase: Passphrase on key.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: KeyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        `ssl.Key` This resource will import SSL certificate key on BIG-IP LTM.
        Certificate key can be imported from certificate key files on the local disk, in PEM format

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip
        import pulumi_std as std

        test_key = f5bigip.ssl.Key("test-key",
            name="serverkey.key",
            content=std.file(input="serverkey.key").result,
            partition="Common")
        ```

        :param str resource_name: The name of the resource.
        :param KeyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(KeyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 content: Optional[pulumi.Input[str]] = None,
                 full_path: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 partition: Optional[pulumi.Input[str]] = None,
                 passphrase: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = KeyArgs.__new__(KeyArgs)

            if content is None and not opts.urn:
                raise TypeError("Missing required property 'content'")
            __props__.__dict__["content"] = None if content is None else pulumi.Output.secret(content)
            __props__.__dict__["full_path"] = full_path
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            __props__.__dict__["partition"] = partition
            __props__.__dict__["passphrase"] = None if passphrase is None else pulumi.Output.secret(passphrase)
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["content", "passphrase"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(Key, __self__).__init__(
            'f5bigip:ssl/key:Key',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            content: Optional[pulumi.Input[str]] = None,
            full_path: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            partition: Optional[pulumi.Input[str]] = None,
            passphrase: Optional[pulumi.Input[str]] = None) -> 'Key':
        """
        Get an existing Key resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] content: Content of SSL certificate key present on local Disk
        :param pulumi.Input[str] full_path: Full Path Name of ssl key
        :param pulumi.Input[str] name: Name of the SSL Certificate key to be Imported on to BIGIP
        :param pulumi.Input[str] partition: Partition of ssl certificate key
        :param pulumi.Input[str] passphrase: Passphrase on key.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _KeyState.__new__(_KeyState)

        __props__.__dict__["content"] = content
        __props__.__dict__["full_path"] = full_path
        __props__.__dict__["name"] = name
        __props__.__dict__["partition"] = partition
        __props__.__dict__["passphrase"] = passphrase
        return Key(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def content(self) -> pulumi.Output[str]:
        """
        Content of SSL certificate key present on local Disk
        """
        return pulumi.get(self, "content")

    @property
    @pulumi.getter(name="fullPath")
    def full_path(self) -> pulumi.Output[str]:
        """
        Full Path Name of ssl key
        """
        return pulumi.get(self, "full_path")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of the SSL Certificate key to be Imported on to BIGIP
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def partition(self) -> pulumi.Output[Optional[str]]:
        """
        Partition of ssl certificate key
        """
        return pulumi.get(self, "partition")

    @property
    @pulumi.getter
    def passphrase(self) -> pulumi.Output[Optional[str]]:
        """
        Passphrase on key.
        """
        return pulumi.get(self, "passphrase")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ProfileTcpArgs', 'ProfileTcp']

@pulumi.input_type
class ProfileTcpArgs:
    def __init__(__self__, *,
                 name: pulumi.Input[str],
                 close_wait_timeout: Optional[pulumi.Input[int]] = None,
                 congestion_control: Optional[pulumi.Input[str]] = None,
                 defaults_from: Optional[pulumi.Input[str]] = None,
                 deferred_accept: Optional[pulumi.Input[str]] = None,
                 delayed_acks: Optional[pulumi.Input[str]] = None,
                 early_retransmit: Optional[pulumi.Input[str]] = None,
                 fast_open: Optional[pulumi.Input[str]] = None,
                 finwait2timeout: Optional[pulumi.Input[int]] = None,
                 finwait_timeout: Optional[pulumi.Input[int]] = None,
                 idle_timeout: Optional[pulumi.Input[int]] = None,
                 initial_congestion_windowsize: Optional[pulumi.Input[int]] = None,
                 keepalive_interval: Optional[pulumi.Input[int]] = None,
                 nagle: Optional[pulumi.Input[str]] = None,
                 partition: Optional[pulumi.Input[str]] = None,
                 proxybuffer_high: Optional[pulumi.Input[int]] = None,
                 receive_windowsize: Optional[pulumi.Input[int]] = None,
                 send_buffersize: Optional[pulumi.Input[int]] = None,
                 tailloss_probe: Optional[pulumi.Input[str]] = None,
                 timewait_recycle: Optional[pulumi.Input[str]] = None,
                 verified_accept: Optional[pulumi.Input[str]] = None,
                 zerowindow_timeout: Optional[pulumi.Input[int]] = None):
        """
        The set of arguments for constructing a ProfileTcp resource.
        :param pulumi.Input[str] name: Name of the LTM TCP Profile,name should be `full path`. The full path is the combination of the `partition + name` (example: /Common/my-pool ) or  `partition + directory + name` of the resource  (example: /Common/test/my-pool )
        :param pulumi.Input[int] close_wait_timeout: Specifies the number of seconds that a connection remains in a LAST-ACK state before quitting. A value of 0 represents a term of forever (or until the maxrtx of the FIN state). The default value is 5 seconds.
        :param pulumi.Input[str] congestion_control: Specifies the algorithm to use to share network resources among competing users to reduce congestion. The default is High Speed.
        :param pulumi.Input[str] defaults_from: Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        :param pulumi.Input[str] deferred_accept: Specifies, when enabled, that the system defers allocation of the connection chain context until the client response is received. This option is useful for dealing with 3-way handshake DOS attacks. The default value is disabled.
        :param pulumi.Input[str] delayed_acks: Specifies, when checked (enabled), that the system can send fewer than one ACK (acknowledgment) segment per data segment received. By default, this setting is enabled.
        :param pulumi.Input[str] early_retransmit: Enabling this setting allows TCP to assume a packet is lost after fewer than the standard number of duplicate ACKs, if there is no way to send new data and generate more duplicate ACKs.
        :param pulumi.Input[str] fast_open: When enabled, permits TCP Fast Open, allowing properly equipped TCP clients to send data with the SYN packet. Default is `enabled`. If `fast_open` set to `enabled`, argument `verified_accept` can't be set to `enabled`.
        :param pulumi.Input[int] finwait2timeout: Specifies the number of seconds that a connection is in the FIN-WAIT-2 state before quitting. The default value is 300 seconds. A value of 0 (zero) represents a term of forever (or until the maxrtx of the FIN state).
        :param pulumi.Input[int] finwait_timeout: Specifies the number of seconds that a connection is in the FIN-WAIT-1 or closing state before quitting. The default value is 5 seconds. A value of 0 (zero) represents a term of forever (or until the maxrtx of the FIN state). You can also specify immediate or indefinite.
        :param pulumi.Input[int] idle_timeout: Specifies the number of seconds that a connection is idle before the connection is eligible for deletion. The default value is 300 seconds.
        :param pulumi.Input[int] initial_congestion_windowsize: Specifies the initial congestion window size for connections to this destination. Actual window size is this value multiplied by the MSS (Maximum Segment Size) for the same connection. The default is 10. Valid values range from 0 to 64.
        :param pulumi.Input[int] keepalive_interval: Specifies the keep alive probe interval, in seconds. The default value is 1800 seconds.
        :param pulumi.Input[str] nagle: Specifies whether the system applies Nagle's algorithm to reduce the number of short segments on the network.If you select Auto, the system determines whether to use Nagle's algorithm based on network conditions. By default, this setting is disabled.
        :param pulumi.Input[str] partition: name of partition
        :param pulumi.Input[int] proxybuffer_high: Specifies the proxy buffer level, in bytes, at which the receive window is closed.
        :param pulumi.Input[int] receive_windowsize: Specifies the maximum advertised RECEIVE window size. This value represents the maximum number of bytes to which the RECEIVE window can scale. The default is 65535 bytes.
        :param pulumi.Input[int] send_buffersize: Specifies the SEND window size. The default is 131072 bytes.
        :param pulumi.Input[str] tailloss_probe: Enabling this setting allows TCP to send a probe segment to trigger fast recovery instead of recovering a loss via a retransmission timeout,By default, this setting is enabled.
        :param pulumi.Input[str] timewait_recycle: Using this setting enabled, the system can recycle a wait-state connection immediately upon receipt of a new connection request instead of having to wait until the connection times out of the wait state. By default, this setting is enabled.
        :param pulumi.Input[str] verified_accept: Specifies, when checked (enabled), that the system can actually communicate with the server before establishing a client connection. To determine this, the system sends the server a SYN packet before responding to the client's SYN with a SYN-ACK. When unchecked, the system accepts the client connection before selecting a server to talk to. By default, this setting is `disabled`.
        :param pulumi.Input[int] zerowindow_timeout: Specifies the timeout in milliseconds for terminating a connection with an effective zero length TCP transmit window.
        """
        pulumi.set(__self__, "name", name)
        if close_wait_timeout is not None:
            pulumi.set(__self__, "close_wait_timeout", close_wait_timeout)
        if congestion_control is not None:
            pulumi.set(__self__, "congestion_control", congestion_control)
        if defaults_from is not None:
            pulumi.set(__self__, "defaults_from", defaults_from)
        if deferred_accept is not None:
            pulumi.set(__self__, "deferred_accept", deferred_accept)
        if delayed_acks is not None:
            pulumi.set(__self__, "delayed_acks", delayed_acks)
        if early_retransmit is not None:
            pulumi.set(__self__, "early_retransmit", early_retransmit)
        if fast_open is not None:
            pulumi.set(__self__, "fast_open", fast_open)
        if finwait2timeout is not None:
            pulumi.set(__self__, "finwait2timeout", finwait2timeout)
        if finwait_timeout is not None:
            pulumi.set(__self__, "finwait_timeout", finwait_timeout)
        if idle_timeout is not None:
            pulumi.set(__self__, "idle_timeout", idle_timeout)
        if initial_congestion_windowsize is not None:
            pulumi.set(__self__, "initial_congestion_windowsize", initial_congestion_windowsize)
        if keepalive_interval is not None:
            pulumi.set(__self__, "keepalive_interval", keepalive_interval)
        if nagle is not None:
            pulumi.set(__self__, "nagle", nagle)
        if partition is not None:
            pulumi.set(__self__, "partition", partition)
        if proxybuffer_high is not None:
            pulumi.set(__self__, "proxybuffer_high", proxybuffer_high)
        if receive_windowsize is not None:
            pulumi.set(__self__, "receive_windowsize", receive_windowsize)
        if send_buffersize is not None:
            pulumi.set(__self__, "send_buffersize", send_buffersize)
        if tailloss_probe is not None:
            pulumi.set(__self__, "tailloss_probe", tailloss_probe)
        if timewait_recycle is not None:
            pulumi.set(__self__, "timewait_recycle", timewait_recycle)
        if verified_accept is not None:
            pulumi.set(__self__, "verified_accept", verified_accept)
        if zerowindow_timeout is not None:
            pulumi.set(__self__, "zerowindow_timeout", zerowindow_timeout)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        """
        Name of the LTM TCP Profile,name should be `full path`. The full path is the combination of the `partition + name` (example: /Common/my-pool ) or  `partition + directory + name` of the resource  (example: /Common/test/my-pool )
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="closeWaitTimeout")
    def close_wait_timeout(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the number of seconds that a connection remains in a LAST-ACK state before quitting. A value of 0 represents a term of forever (or until the maxrtx of the FIN state). The default value is 5 seconds.
        """
        return pulumi.get(self, "close_wait_timeout")

    @close_wait_timeout.setter
    def close_wait_timeout(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "close_wait_timeout", value)

    @property
    @pulumi.getter(name="congestionControl")
    def congestion_control(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the algorithm to use to share network resources among competing users to reduce congestion. The default is High Speed.
        """
        return pulumi.get(self, "congestion_control")

    @congestion_control.setter
    def congestion_control(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "congestion_control", value)

    @property
    @pulumi.getter(name="defaultsFrom")
    def defaults_from(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        """
        return pulumi.get(self, "defaults_from")

    @defaults_from.setter
    def defaults_from(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "defaults_from", value)

    @property
    @pulumi.getter(name="deferredAccept")
    def deferred_accept(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies, when enabled, that the system defers allocation of the connection chain context until the client response is received. This option is useful for dealing with 3-way handshake DOS attacks. The default value is disabled.
        """
        return pulumi.get(self, "deferred_accept")

    @deferred_accept.setter
    def deferred_accept(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "deferred_accept", value)

    @property
    @pulumi.getter(name="delayedAcks")
    def delayed_acks(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies, when checked (enabled), that the system can send fewer than one ACK (acknowledgment) segment per data segment received. By default, this setting is enabled.
        """
        return pulumi.get(self, "delayed_acks")

    @delayed_acks.setter
    def delayed_acks(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "delayed_acks", value)

    @property
    @pulumi.getter(name="earlyRetransmit")
    def early_retransmit(self) -> Optional[pulumi.Input[str]]:
        """
        Enabling this setting allows TCP to assume a packet is lost after fewer than the standard number of duplicate ACKs, if there is no way to send new data and generate more duplicate ACKs.
        """
        return pulumi.get(self, "early_retransmit")

    @early_retransmit.setter
    def early_retransmit(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "early_retransmit", value)

    @property
    @pulumi.getter(name="fastOpen")
    def fast_open(self) -> Optional[pulumi.Input[str]]:
        """
        When enabled, permits TCP Fast Open, allowing properly equipped TCP clients to send data with the SYN packet. Default is `enabled`. If `fast_open` set to `enabled`, argument `verified_accept` can't be set to `enabled`.
        """
        return pulumi.get(self, "fast_open")

    @fast_open.setter
    def fast_open(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "fast_open", value)

    @property
    @pulumi.getter
    def finwait2timeout(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the number of seconds that a connection is in the FIN-WAIT-2 state before quitting. The default value is 300 seconds. A value of 0 (zero) represents a term of forever (or until the maxrtx of the FIN state).
        """
        return pulumi.get(self, "finwait2timeout")

    @finwait2timeout.setter
    def finwait2timeout(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "finwait2timeout", value)

    @property
    @pulumi.getter(name="finwaitTimeout")
    def finwait_timeout(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the number of seconds that a connection is in the FIN-WAIT-1 or closing state before quitting. The default value is 5 seconds. A value of 0 (zero) represents a term of forever (or until the maxrtx of the FIN state). You can also specify immediate or indefinite.
        """
        return pulumi.get(self, "finwait_timeout")

    @finwait_timeout.setter
    def finwait_timeout(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "finwait_timeout", value)

    @property
    @pulumi.getter(name="idleTimeout")
    def idle_timeout(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the number of seconds that a connection is idle before the connection is eligible for deletion. The default value is 300 seconds.
        """
        return pulumi.get(self, "idle_timeout")

    @idle_timeout.setter
    def idle_timeout(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "idle_timeout", value)

    @property
    @pulumi.getter(name="initialCongestionWindowsize")
    def initial_congestion_windowsize(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the initial congestion window size for connections to this destination. Actual window size is this value multiplied by the MSS (Maximum Segment Size) for the same connection. The default is 10. Valid values range from 0 to 64.
        """
        return pulumi.get(self, "initial_congestion_windowsize")

    @initial_congestion_windowsize.setter
    def initial_congestion_windowsize(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "initial_congestion_windowsize", value)

    @property
    @pulumi.getter(name="keepaliveInterval")
    def keepalive_interval(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the keep alive probe interval, in seconds. The default value is 1800 seconds.
        """
        return pulumi.get(self, "keepalive_interval")

    @keepalive_interval.setter
    def keepalive_interval(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "keepalive_interval", value)

    @property
    @pulumi.getter
    def nagle(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies whether the system applies Nagle's algorithm to reduce the number of short segments on the network.If you select Auto, the system determines whether to use Nagle's algorithm based on network conditions. By default, this setting is disabled.
        """
        return pulumi.get(self, "nagle")

    @nagle.setter
    def nagle(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "nagle", value)

    @property
    @pulumi.getter
    def partition(self) -> Optional[pulumi.Input[str]]:
        """
        name of partition
        """
        return pulumi.get(self, "partition")

    @partition.setter
    def partition(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "partition", value)

    @property
    @pulumi.getter(name="proxybufferHigh")
    def proxybuffer_high(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the proxy buffer level, in bytes, at which the receive window is closed.
        """
        return pulumi.get(self, "proxybuffer_high")

    @proxybuffer_high.setter
    def proxybuffer_high(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "proxybuffer_high", value)

    @property
    @pulumi.getter(name="receiveWindowsize")
    def receive_windowsize(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the maximum advertised RECEIVE window size. This value represents the maximum number of bytes to which the RECEIVE window can scale. The default is 65535 bytes.
        """
        return pulumi.get(self, "receive_windowsize")

    @receive_windowsize.setter
    def receive_windowsize(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "receive_windowsize", value)

    @property
    @pulumi.getter(name="sendBuffersize")
    def send_buffersize(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the SEND window size. The default is 131072 bytes.
        """
        return pulumi.get(self, "send_buffersize")

    @send_buffersize.setter
    def send_buffersize(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "send_buffersize", value)

    @property
    @pulumi.getter(name="taillossProbe")
    def tailloss_probe(self) -> Optional[pulumi.Input[str]]:
        """
        Enabling this setting allows TCP to send a probe segment to trigger fast recovery instead of recovering a loss via a retransmission timeout,By default, this setting is enabled.
        """
        return pulumi.get(self, "tailloss_probe")

    @tailloss_probe.setter
    def tailloss_probe(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tailloss_probe", value)

    @property
    @pulumi.getter(name="timewaitRecycle")
    def timewait_recycle(self) -> Optional[pulumi.Input[str]]:
        """
        Using this setting enabled, the system can recycle a wait-state connection immediately upon receipt of a new connection request instead of having to wait until the connection times out of the wait state. By default, this setting is enabled.
        """
        return pulumi.get(self, "timewait_recycle")

    @timewait_recycle.setter
    def timewait_recycle(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "timewait_recycle", value)

    @property
    @pulumi.getter(name="verifiedAccept")
    def verified_accept(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies, when checked (enabled), that the system can actually communicate with the server before establishing a client connection. To determine this, the system sends the server a SYN packet before responding to the client's SYN with a SYN-ACK. When unchecked, the system accepts the client connection before selecting a server to talk to. By default, this setting is `disabled`.
        """
        return pulumi.get(self, "verified_accept")

    @verified_accept.setter
    def verified_accept(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "verified_accept", value)

    @property
    @pulumi.getter(name="zerowindowTimeout")
    def zerowindow_timeout(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the timeout in milliseconds for terminating a connection with an effective zero length TCP transmit window.
        """
        return pulumi.get(self, "zerowindow_timeout")

    @zerowindow_timeout.setter
    def zerowindow_timeout(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "zerowindow_timeout", value)


@pulumi.input_type
class _ProfileTcpState:
    def __init__(__self__, *,
                 close_wait_timeout: Optional[pulumi.Input[int]] = None,
                 congestion_control: Optional[pulumi.Input[str]] = None,
                 defaults_from: Optional[pulumi.Input[str]] = None,
                 deferred_accept: Optional[pulumi.Input[str]] = None,
                 delayed_acks: Optional[pulumi.Input[str]] = None,
                 early_retransmit: Optional[pulumi.Input[str]] = None,
                 fast_open: Optional[pulumi.Input[str]] = None,
                 finwait2timeout: Optional[pulumi.Input[int]] = None,
                 finwait_timeout: Optional[pulumi.Input[int]] = None,
                 idle_timeout: Optional[pulumi.Input[int]] = None,
                 initial_congestion_windowsize: Optional[pulumi.Input[int]] = None,
                 keepalive_interval: Optional[pulumi.Input[int]] = None,
                 nagle: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 partition: Optional[pulumi.Input[str]] = None,
                 proxybuffer_high: Optional[pulumi.Input[int]] = None,
                 receive_windowsize: Optional[pulumi.Input[int]] = None,
                 send_buffersize: Optional[pulumi.Input[int]] = None,
                 tailloss_probe: Optional[pulumi.Input[str]] = None,
                 timewait_recycle: Optional[pulumi.Input[str]] = None,
                 verified_accept: Optional[pulumi.Input[str]] = None,
                 zerowindow_timeout: Optional[pulumi.Input[int]] = None):
        """
        Input properties used for looking up and filtering ProfileTcp resources.
        :param pulumi.Input[int] close_wait_timeout: Specifies the number of seconds that a connection remains in a LAST-ACK state before quitting. A value of 0 represents a term of forever (or until the maxrtx of the FIN state). The default value is 5 seconds.
        :param pulumi.Input[str] congestion_control: Specifies the algorithm to use to share network resources among competing users to reduce congestion. The default is High Speed.
        :param pulumi.Input[str] defaults_from: Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        :param pulumi.Input[str] deferred_accept: Specifies, when enabled, that the system defers allocation of the connection chain context until the client response is received. This option is useful for dealing with 3-way handshake DOS attacks. The default value is disabled.
        :param pulumi.Input[str] delayed_acks: Specifies, when checked (enabled), that the system can send fewer than one ACK (acknowledgment) segment per data segment received. By default, this setting is enabled.
        :param pulumi.Input[str] early_retransmit: Enabling this setting allows TCP to assume a packet is lost after fewer than the standard number of duplicate ACKs, if there is no way to send new data and generate more duplicate ACKs.
        :param pulumi.Input[str] fast_open: When enabled, permits TCP Fast Open, allowing properly equipped TCP clients to send data with the SYN packet. Default is `enabled`. If `fast_open` set to `enabled`, argument `verified_accept` can't be set to `enabled`.
        :param pulumi.Input[int] finwait2timeout: Specifies the number of seconds that a connection is in the FIN-WAIT-2 state before quitting. The default value is 300 seconds. A value of 0 (zero) represents a term of forever (or until the maxrtx of the FIN state).
        :param pulumi.Input[int] finwait_timeout: Specifies the number of seconds that a connection is in the FIN-WAIT-1 or closing state before quitting. The default value is 5 seconds. A value of 0 (zero) represents a term of forever (or until the maxrtx of the FIN state). You can also specify immediate or indefinite.
        :param pulumi.Input[int] idle_timeout: Specifies the number of seconds that a connection is idle before the connection is eligible for deletion. The default value is 300 seconds.
        :param pulumi.Input[int] initial_congestion_windowsize: Specifies the initial congestion window size for connections to this destination. Actual window size is this value multiplied by the MSS (Maximum Segment Size) for the same connection. The default is 10. Valid values range from 0 to 64.
        :param pulumi.Input[int] keepalive_interval: Specifies the keep alive probe interval, in seconds. The default value is 1800 seconds.
        :param pulumi.Input[str] nagle: Specifies whether the system applies Nagle's algorithm to reduce the number of short segments on the network.If you select Auto, the system determines whether to use Nagle's algorithm based on network conditions. By default, this setting is disabled.
        :param pulumi.Input[str] name: Name of the LTM TCP Profile,name should be `full path`. The full path is the combination of the `partition + name` (example: /Common/my-pool ) or  `partition + directory + name` of the resource  (example: /Common/test/my-pool )
        :param pulumi.Input[str] partition: name of partition
        :param pulumi.Input[int] proxybuffer_high: Specifies the proxy buffer level, in bytes, at which the receive window is closed.
        :param pulumi.Input[int] receive_windowsize: Specifies the maximum advertised RECEIVE window size. This value represents the maximum number of bytes to which the RECEIVE window can scale. The default is 65535 bytes.
        :param pulumi.Input[int] send_buffersize: Specifies the SEND window size. The default is 131072 bytes.
        :param pulumi.Input[str] tailloss_probe: Enabling this setting allows TCP to send a probe segment to trigger fast recovery instead of recovering a loss via a retransmission timeout,By default, this setting is enabled.
        :param pulumi.Input[str] timewait_recycle: Using this setting enabled, the system can recycle a wait-state connection immediately upon receipt of a new connection request instead of having to wait until the connection times out of the wait state. By default, this setting is enabled.
        :param pulumi.Input[str] verified_accept: Specifies, when checked (enabled), that the system can actually communicate with the server before establishing a client connection. To determine this, the system sends the server a SYN packet before responding to the client's SYN with a SYN-ACK. When unchecked, the system accepts the client connection before selecting a server to talk to. By default, this setting is `disabled`.
        :param pulumi.Input[int] zerowindow_timeout: Specifies the timeout in milliseconds for terminating a connection with an effective zero length TCP transmit window.
        """
        if close_wait_timeout is not None:
            pulumi.set(__self__, "close_wait_timeout", close_wait_timeout)
        if congestion_control is not None:
            pulumi.set(__self__, "congestion_control", congestion_control)
        if defaults_from is not None:
            pulumi.set(__self__, "defaults_from", defaults_from)
        if deferred_accept is not None:
            pulumi.set(__self__, "deferred_accept", deferred_accept)
        if delayed_acks is not None:
            pulumi.set(__self__, "delayed_acks", delayed_acks)
        if early_retransmit is not None:
            pulumi.set(__self__, "early_retransmit", early_retransmit)
        if fast_open is not None:
            pulumi.set(__self__, "fast_open", fast_open)
        if finwait2timeout is not None:
            pulumi.set(__self__, "finwait2timeout", finwait2timeout)
        if finwait_timeout is not None:
            pulumi.set(__self__, "finwait_timeout", finwait_timeout)
        if idle_timeout is not None:
            pulumi.set(__self__, "idle_timeout", idle_timeout)
        if initial_congestion_windowsize is not None:
            pulumi.set(__self__, "initial_congestion_windowsize", initial_congestion_windowsize)
        if keepalive_interval is not None:
            pulumi.set(__self__, "keepalive_interval", keepalive_interval)
        if nagle is not None:
            pulumi.set(__self__, "nagle", nagle)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if partition is not None:
            pulumi.set(__self__, "partition", partition)
        if proxybuffer_high is not None:
            pulumi.set(__self__, "proxybuffer_high", proxybuffer_high)
        if receive_windowsize is not None:
            pulumi.set(__self__, "receive_windowsize", receive_windowsize)
        if send_buffersize is not None:
            pulumi.set(__self__, "send_buffersize", send_buffersize)
        if tailloss_probe is not None:
            pulumi.set(__self__, "tailloss_probe", tailloss_probe)
        if timewait_recycle is not None:
            pulumi.set(__self__, "timewait_recycle", timewait_recycle)
        if verified_accept is not None:
            pulumi.set(__self__, "verified_accept", verified_accept)
        if zerowindow_timeout is not None:
            pulumi.set(__self__, "zerowindow_timeout", zerowindow_timeout)

    @property
    @pulumi.getter(name="closeWaitTimeout")
    def close_wait_timeout(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the number of seconds that a connection remains in a LAST-ACK state before quitting. A value of 0 represents a term of forever (or until the maxrtx of the FIN state). The default value is 5 seconds.
        """
        return pulumi.get(self, "close_wait_timeout")

    @close_wait_timeout.setter
    def close_wait_timeout(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "close_wait_timeout", value)

    @property
    @pulumi.getter(name="congestionControl")
    def congestion_control(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the algorithm to use to share network resources among competing users to reduce congestion. The default is High Speed.
        """
        return pulumi.get(self, "congestion_control")

    @congestion_control.setter
    def congestion_control(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "congestion_control", value)

    @property
    @pulumi.getter(name="defaultsFrom")
    def defaults_from(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        """
        return pulumi.get(self, "defaults_from")

    @defaults_from.setter
    def defaults_from(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "defaults_from", value)

    @property
    @pulumi.getter(name="deferredAccept")
    def deferred_accept(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies, when enabled, that the system defers allocation of the connection chain context until the client response is received. This option is useful for dealing with 3-way handshake DOS attacks. The default value is disabled.
        """
        return pulumi.get(self, "deferred_accept")

    @deferred_accept.setter
    def deferred_accept(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "deferred_accept", value)

    @property
    @pulumi.getter(name="delayedAcks")
    def delayed_acks(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies, when checked (enabled), that the system can send fewer than one ACK (acknowledgment) segment per data segment received. By default, this setting is enabled.
        """
        return pulumi.get(self, "delayed_acks")

    @delayed_acks.setter
    def delayed_acks(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "delayed_acks", value)

    @property
    @pulumi.getter(name="earlyRetransmit")
    def early_retransmit(self) -> Optional[pulumi.Input[str]]:
        """
        Enabling this setting allows TCP to assume a packet is lost after fewer than the standard number of duplicate ACKs, if there is no way to send new data and generate more duplicate ACKs.
        """
        return pulumi.get(self, "early_retransmit")

    @early_retransmit.setter
    def early_retransmit(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "early_retransmit", value)

    @property
    @pulumi.getter(name="fastOpen")
    def fast_open(self) -> Optional[pulumi.Input[str]]:
        """
        When enabled, permits TCP Fast Open, allowing properly equipped TCP clients to send data with the SYN packet. Default is `enabled`. If `fast_open` set to `enabled`, argument `verified_accept` can't be set to `enabled`.
        """
        return pulumi.get(self, "fast_open")

    @fast_open.setter
    def fast_open(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "fast_open", value)

    @property
    @pulumi.getter
    def finwait2timeout(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the number of seconds that a connection is in the FIN-WAIT-2 state before quitting. The default value is 300 seconds. A value of 0 (zero) represents a term of forever (or until the maxrtx of the FIN state).
        """
        return pulumi.get(self, "finwait2timeout")

    @finwait2timeout.setter
    def finwait2timeout(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "finwait2timeout", value)

    @property
    @pulumi.getter(name="finwaitTimeout")
    def finwait_timeout(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the number of seconds that a connection is in the FIN-WAIT-1 or closing state before quitting. The default value is 5 seconds. A value of 0 (zero) represents a term of forever (or until the maxrtx of the FIN state). You can also specify immediate or indefinite.
        """
        return pulumi.get(self, "finwait_timeout")

    @finwait_timeout.setter
    def finwait_timeout(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "finwait_timeout", value)

    @property
    @pulumi.getter(name="idleTimeout")
    def idle_timeout(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the number of seconds that a connection is idle before the connection is eligible for deletion. The default value is 300 seconds.
        """
        return pulumi.get(self, "idle_timeout")

    @idle_timeout.setter
    def idle_timeout(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "idle_timeout", value)

    @property
    @pulumi.getter(name="initialCongestionWindowsize")
    def initial_congestion_windowsize(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the initial congestion window size for connections to this destination. Actual window size is this value multiplied by the MSS (Maximum Segment Size) for the same connection. The default is 10. Valid values range from 0 to 64.
        """
        return pulumi.get(self, "initial_congestion_windowsize")

    @initial_congestion_windowsize.setter
    def initial_congestion_windowsize(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "initial_congestion_windowsize", value)

    @property
    @pulumi.getter(name="keepaliveInterval")
    def keepalive_interval(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the keep alive probe interval, in seconds. The default value is 1800 seconds.
        """
        return pulumi.get(self, "keepalive_interval")

    @keepalive_interval.setter
    def keepalive_interval(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "keepalive_interval", value)

    @property
    @pulumi.getter
    def nagle(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies whether the system applies Nagle's algorithm to reduce the number of short segments on the network.If you select Auto, the system determines whether to use Nagle's algorithm based on network conditions. By default, this setting is disabled.
        """
        return pulumi.get(self, "nagle")

    @nagle.setter
    def nagle(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "nagle", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the LTM TCP Profile,name should be `full path`. The full path is the combination of the `partition + name` (example: /Common/my-pool ) or  `partition + directory + name` of the resource  (example: /Common/test/my-pool )
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def partition(self) -> Optional[pulumi.Input[str]]:
        """
        name of partition
        """
        return pulumi.get(self, "partition")

    @partition.setter
    def partition(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "partition", value)

    @property
    @pulumi.getter(name="proxybufferHigh")
    def proxybuffer_high(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the proxy buffer level, in bytes, at which the receive window is closed.
        """
        return pulumi.get(self, "proxybuffer_high")

    @proxybuffer_high.setter
    def proxybuffer_high(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "proxybuffer_high", value)

    @property
    @pulumi.getter(name="receiveWindowsize")
    def receive_windowsize(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the maximum advertised RECEIVE window size. This value represents the maximum number of bytes to which the RECEIVE window can scale. The default is 65535 bytes.
        """
        return pulumi.get(self, "receive_windowsize")

    @receive_windowsize.setter
    def receive_windowsize(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "receive_windowsize", value)

    @property
    @pulumi.getter(name="sendBuffersize")
    def send_buffersize(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the SEND window size. The default is 131072 bytes.
        """
        return pulumi.get(self, "send_buffersize")

    @send_buffersize.setter
    def send_buffersize(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "send_buffersize", value)

    @property
    @pulumi.getter(name="taillossProbe")
    def tailloss_probe(self) -> Optional[pulumi.Input[str]]:
        """
        Enabling this setting allows TCP to send a probe segment to trigger fast recovery instead of recovering a loss via a retransmission timeout,By default, this setting is enabled.
        """
        return pulumi.get(self, "tailloss_probe")

    @tailloss_probe.setter
    def tailloss_probe(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tailloss_probe", value)

    @property
    @pulumi.getter(name="timewaitRecycle")
    def timewait_recycle(self) -> Optional[pulumi.Input[str]]:
        """
        Using this setting enabled, the system can recycle a wait-state connection immediately upon receipt of a new connection request instead of having to wait until the connection times out of the wait state. By default, this setting is enabled.
        """
        return pulumi.get(self, "timewait_recycle")

    @timewait_recycle.setter
    def timewait_recycle(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "timewait_recycle", value)

    @property
    @pulumi.getter(name="verifiedAccept")
    def verified_accept(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies, when checked (enabled), that the system can actually communicate with the server before establishing a client connection. To determine this, the system sends the server a SYN packet before responding to the client's SYN with a SYN-ACK. When unchecked, the system accepts the client connection before selecting a server to talk to. By default, this setting is `disabled`.
        """
        return pulumi.get(self, "verified_accept")

    @verified_accept.setter
    def verified_accept(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "verified_accept", value)

    @property
    @pulumi.getter(name="zerowindowTimeout")
    def zerowindow_timeout(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the timeout in milliseconds for terminating a connection with an effective zero length TCP transmit window.
        """
        return pulumi.get(self, "zerowindow_timeout")

    @zerowindow_timeout.setter
    def zerowindow_timeout(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "zerowindow_timeout", value)


class ProfileTcp(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 close_wait_timeout: Optional[pulumi.Input[int]] = None,
                 congestion_control: Optional[pulumi.Input[str]] = None,
                 defaults_from: Optional[pulumi.Input[str]] = None,
                 deferred_accept: Optional[pulumi.Input[str]] = None,
                 delayed_acks: Optional[pulumi.Input[str]] = None,
                 early_retransmit: Optional[pulumi.Input[str]] = None,
                 fast_open: Optional[pulumi.Input[str]] = None,
                 finwait2timeout: Optional[pulumi.Input[int]] = None,
                 finwait_timeout: Optional[pulumi.Input[int]] = None,
                 idle_timeout: Optional[pulumi.Input[int]] = None,
                 initial_congestion_windowsize: Optional[pulumi.Input[int]] = None,
                 keepalive_interval: Optional[pulumi.Input[int]] = None,
                 nagle: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 partition: Optional[pulumi.Input[str]] = None,
                 proxybuffer_high: Optional[pulumi.Input[int]] = None,
                 receive_windowsize: Optional[pulumi.Input[int]] = None,
                 send_buffersize: Optional[pulumi.Input[int]] = None,
                 tailloss_probe: Optional[pulumi.Input[str]] = None,
                 timewait_recycle: Optional[pulumi.Input[str]] = None,
                 verified_accept: Optional[pulumi.Input[str]] = None,
                 zerowindow_timeout: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        """
        `ltm.ProfileTcp` Configures a custom TCP LTM Profile for use by health checks.

        Resources should be named with their `full path`. The full path is the combination of the `partition + name` (example: /Common/my-pool ) or  `partition + directory + name` of the resource  (example: /Common/test/my-pool )

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        sanjose_tcp_lan_profile = f5bigip.ltm.ProfileTcp("sanjose-tcp-lan-profile",
            name="/Common/sanjose-tcp-lan-profile",
            idle_timeout=200,
            close_wait_timeout=5,
            finwait2timeout=5,
            finwait_timeout=300,
            keepalive_interval=1700,
            deferred_accept="enabled",
            fast_open="enabled")
        ```

        ## Importing

        An existing tcp profile can be imported into this resource by supplying tcp profile Name in `full path` as `id`.
        An example is below:
        ```sh
        $ terraform import bigip_ltm_profile_tcp.tcp-lan-profile-import /Common/test-tcp-lan-profile
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] close_wait_timeout: Specifies the number of seconds that a connection remains in a LAST-ACK state before quitting. A value of 0 represents a term of forever (or until the maxrtx of the FIN state). The default value is 5 seconds.
        :param pulumi.Input[str] congestion_control: Specifies the algorithm to use to share network resources among competing users to reduce congestion. The default is High Speed.
        :param pulumi.Input[str] defaults_from: Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        :param pulumi.Input[str] deferred_accept: Specifies, when enabled, that the system defers allocation of the connection chain context until the client response is received. This option is useful for dealing with 3-way handshake DOS attacks. The default value is disabled.
        :param pulumi.Input[str] delayed_acks: Specifies, when checked (enabled), that the system can send fewer than one ACK (acknowledgment) segment per data segment received. By default, this setting is enabled.
        :param pulumi.Input[str] early_retransmit: Enabling this setting allows TCP to assume a packet is lost after fewer than the standard number of duplicate ACKs, if there is no way to send new data and generate more duplicate ACKs.
        :param pulumi.Input[str] fast_open: When enabled, permits TCP Fast Open, allowing properly equipped TCP clients to send data with the SYN packet. Default is `enabled`. If `fast_open` set to `enabled`, argument `verified_accept` can't be set to `enabled`.
        :param pulumi.Input[int] finwait2timeout: Specifies the number of seconds that a connection is in the FIN-WAIT-2 state before quitting. The default value is 300 seconds. A value of 0 (zero) represents a term of forever (or until the maxrtx of the FIN state).
        :param pulumi.Input[int] finwait_timeout: Specifies the number of seconds that a connection is in the FIN-WAIT-1 or closing state before quitting. The default value is 5 seconds. A value of 0 (zero) represents a term of forever (or until the maxrtx of the FIN state). You can also specify immediate or indefinite.
        :param pulumi.Input[int] idle_timeout: Specifies the number of seconds that a connection is idle before the connection is eligible for deletion. The default value is 300 seconds.
        :param pulumi.Input[int] initial_congestion_windowsize: Specifies the initial congestion window size for connections to this destination. Actual window size is this value multiplied by the MSS (Maximum Segment Size) for the same connection. The default is 10. Valid values range from 0 to 64.
        :param pulumi.Input[int] keepalive_interval: Specifies the keep alive probe interval, in seconds. The default value is 1800 seconds.
        :param pulumi.Input[str] nagle: Specifies whether the system applies Nagle's algorithm to reduce the number of short segments on the network.If you select Auto, the system determines whether to use Nagle's algorithm based on network conditions. By default, this setting is disabled.
        :param pulumi.Input[str] name: Name of the LTM TCP Profile,name should be `full path`. The full path is the combination of the `partition + name` (example: /Common/my-pool ) or  `partition + directory + name` of the resource  (example: /Common/test/my-pool )
        :param pulumi.Input[str] partition: name of partition
        :param pulumi.Input[int] proxybuffer_high: Specifies the proxy buffer level, in bytes, at which the receive window is closed.
        :param pulumi.Input[int] receive_windowsize: Specifies the maximum advertised RECEIVE window size. This value represents the maximum number of bytes to which the RECEIVE window can scale. The default is 65535 bytes.
        :param pulumi.Input[int] send_buffersize: Specifies the SEND window size. The default is 131072 bytes.
        :param pulumi.Input[str] tailloss_probe: Enabling this setting allows TCP to send a probe segment to trigger fast recovery instead of recovering a loss via a retransmission timeout,By default, this setting is enabled.
        :param pulumi.Input[str] timewait_recycle: Using this setting enabled, the system can recycle a wait-state connection immediately upon receipt of a new connection request instead of having to wait until the connection times out of the wait state. By default, this setting is enabled.
        :param pulumi.Input[str] verified_accept: Specifies, when checked (enabled), that the system can actually communicate with the server before establishing a client connection. To determine this, the system sends the server a SYN packet before responding to the client's SYN with a SYN-ACK. When unchecked, the system accepts the client connection before selecting a server to talk to. By default, this setting is `disabled`.
        :param pulumi.Input[int] zerowindow_timeout: Specifies the timeout in milliseconds for terminating a connection with an effective zero length TCP transmit window.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProfileTcpArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        `ltm.ProfileTcp` Configures a custom TCP LTM Profile for use by health checks.

        Resources should be named with their `full path`. The full path is the combination of the `partition + name` (example: /Common/my-pool ) or  `partition + directory + name` of the resource  (example: /Common/test/my-pool )

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        sanjose_tcp_lan_profile = f5bigip.ltm.ProfileTcp("sanjose-tcp-lan-profile",
            name="/Common/sanjose-tcp-lan-profile",
            idle_timeout=200,
            close_wait_timeout=5,
            finwait2timeout=5,
            finwait_timeout=300,
            keepalive_interval=1700,
            deferred_accept="enabled",
            fast_open="enabled")
        ```

        ## Importing

        An existing tcp profile can be imported into this resource by supplying tcp profile Name in `full path` as `id`.
        An example is below:
        ```sh
        $ terraform import bigip_ltm_profile_tcp.tcp-lan-profile-import /Common/test-tcp-lan-profile
        ```

        :param str resource_name: The name of the resource.
        :param ProfileTcpArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProfileTcpArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 close_wait_timeout: Optional[pulumi.Input[int]] = None,
                 congestion_control: Optional[pulumi.Input[str]] = None,
                 defaults_from: Optional[pulumi.Input[str]] = None,
                 deferred_accept: Optional[pulumi.Input[str]] = None,
                 delayed_acks: Optional[pulumi.Input[str]] = None,
                 early_retransmit: Optional[pulumi.Input[str]] = None,
                 fast_open: Optional[pulumi.Input[str]] = None,
                 finwait2timeout: Optional[pulumi.Input[int]] = None,
                 finwait_timeout: Optional[pulumi.Input[int]] = None,
                 idle_timeout: Optional[pulumi.Input[int]] = None,
                 initial_congestion_windowsize: Optional[pulumi.Input[int]] = None,
                 keepalive_interval: Optional[pulumi.Input[int]] = None,
                 nagle: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 partition: Optional[pulumi.Input[str]] = None,
                 proxybuffer_high: Optional[pulumi.Input[int]] = None,
                 receive_windowsize: Optional[pulumi.Input[int]] = None,
                 send_buffersize: Optional[pulumi.Input[int]] = None,
                 tailloss_probe: Optional[pulumi.Input[str]] = None,
                 timewait_recycle: Optional[pulumi.Input[str]] = None,
                 verified_accept: Optional[pulumi.Input[str]] = None,
                 zerowindow_timeout: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProfileTcpArgs.__new__(ProfileTcpArgs)

            __props__.__dict__["close_wait_timeout"] = close_wait_timeout
            __props__.__dict__["congestion_control"] = congestion_control
            __props__.__dict__["defaults_from"] = defaults_from
            __props__.__dict__["deferred_accept"] = deferred_accept
            __props__.__dict__["delayed_acks"] = delayed_acks
            __props__.__dict__["early_retransmit"] = early_retransmit
            __props__.__dict__["fast_open"] = fast_open
            __props__.__dict__["finwait2timeout"] = finwait2timeout
            __props__.__dict__["finwait_timeout"] = finwait_timeout
            __props__.__dict__["idle_timeout"] = idle_timeout
            __props__.__dict__["initial_congestion_windowsize"] = initial_congestion_windowsize
            __props__.__dict__["keepalive_interval"] = keepalive_interval
            __props__.__dict__["nagle"] = nagle
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            __props__.__dict__["partition"] = partition
            __props__.__dict__["proxybuffer_high"] = proxybuffer_high
            __props__.__dict__["receive_windowsize"] = receive_windowsize
            __props__.__dict__["send_buffersize"] = send_buffersize
            __props__.__dict__["tailloss_probe"] = tailloss_probe
            __props__.__dict__["timewait_recycle"] = timewait_recycle
            __props__.__dict__["verified_accept"] = verified_accept
            __props__.__dict__["zerowindow_timeout"] = zerowindow_timeout
        super(ProfileTcp, __self__).__init__(
            'f5bigip:ltm/profileTcp:ProfileTcp',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            close_wait_timeout: Optional[pulumi.Input[int]] = None,
            congestion_control: Optional[pulumi.Input[str]] = None,
            defaults_from: Optional[pulumi.Input[str]] = None,
            deferred_accept: Optional[pulumi.Input[str]] = None,
            delayed_acks: Optional[pulumi.Input[str]] = None,
            early_retransmit: Optional[pulumi.Input[str]] = None,
            fast_open: Optional[pulumi.Input[str]] = None,
            finwait2timeout: Optional[pulumi.Input[int]] = None,
            finwait_timeout: Optional[pulumi.Input[int]] = None,
            idle_timeout: Optional[pulumi.Input[int]] = None,
            initial_congestion_windowsize: Optional[pulumi.Input[int]] = None,
            keepalive_interval: Optional[pulumi.Input[int]] = None,
            nagle: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            partition: Optional[pulumi.Input[str]] = None,
            proxybuffer_high: Optional[pulumi.Input[int]] = None,
            receive_windowsize: Optional[pulumi.Input[int]] = None,
            send_buffersize: Optional[pulumi.Input[int]] = None,
            tailloss_probe: Optional[pulumi.Input[str]] = None,
            timewait_recycle: Optional[pulumi.Input[str]] = None,
            verified_accept: Optional[pulumi.Input[str]] = None,
            zerowindow_timeout: Optional[pulumi.Input[int]] = None) -> 'ProfileTcp':
        """
        Get an existing ProfileTcp resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] close_wait_timeout: Specifies the number of seconds that a connection remains in a LAST-ACK state before quitting. A value of 0 represents a term of forever (or until the maxrtx of the FIN state). The default value is 5 seconds.
        :param pulumi.Input[str] congestion_control: Specifies the algorithm to use to share network resources among competing users to reduce congestion. The default is High Speed.
        :param pulumi.Input[str] defaults_from: Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        :param pulumi.Input[str] deferred_accept: Specifies, when enabled, that the system defers allocation of the connection chain context until the client response is received. This option is useful for dealing with 3-way handshake DOS attacks. The default value is disabled.
        :param pulumi.Input[str] delayed_acks: Specifies, when checked (enabled), that the system can send fewer than one ACK (acknowledgment) segment per data segment received. By default, this setting is enabled.
        :param pulumi.Input[str] early_retransmit: Enabling this setting allows TCP to assume a packet is lost after fewer than the standard number of duplicate ACKs, if there is no way to send new data and generate more duplicate ACKs.
        :param pulumi.Input[str] fast_open: When enabled, permits TCP Fast Open, allowing properly equipped TCP clients to send data with the SYN packet. Default is `enabled`. If `fast_open` set to `enabled`, argument `verified_accept` can't be set to `enabled`.
        :param pulumi.Input[int] finwait2timeout: Specifies the number of seconds that a connection is in the FIN-WAIT-2 state before quitting. The default value is 300 seconds. A value of 0 (zero) represents a term of forever (or until the maxrtx of the FIN state).
        :param pulumi.Input[int] finwait_timeout: Specifies the number of seconds that a connection is in the FIN-WAIT-1 or closing state before quitting. The default value is 5 seconds. A value of 0 (zero) represents a term of forever (or until the maxrtx of the FIN state). You can also specify immediate or indefinite.
        :param pulumi.Input[int] idle_timeout: Specifies the number of seconds that a connection is idle before the connection is eligible for deletion. The default value is 300 seconds.
        :param pulumi.Input[int] initial_congestion_windowsize: Specifies the initial congestion window size for connections to this destination. Actual window size is this value multiplied by the MSS (Maximum Segment Size) for the same connection. The default is 10. Valid values range from 0 to 64.
        :param pulumi.Input[int] keepalive_interval: Specifies the keep alive probe interval, in seconds. The default value is 1800 seconds.
        :param pulumi.Input[str] nagle: Specifies whether the system applies Nagle's algorithm to reduce the number of short segments on the network.If you select Auto, the system determines whether to use Nagle's algorithm based on network conditions. By default, this setting is disabled.
        :param pulumi.Input[str] name: Name of the LTM TCP Profile,name should be `full path`. The full path is the combination of the `partition + name` (example: /Common/my-pool ) or  `partition + directory + name` of the resource  (example: /Common/test/my-pool )
        :param pulumi.Input[str] partition: name of partition
        :param pulumi.Input[int] proxybuffer_high: Specifies the proxy buffer level, in bytes, at which the receive window is closed.
        :param pulumi.Input[int] receive_windowsize: Specifies the maximum advertised RECEIVE window size. This value represents the maximum number of bytes to which the RECEIVE window can scale. The default is 65535 bytes.
        :param pulumi.Input[int] send_buffersize: Specifies the SEND window size. The default is 131072 bytes.
        :param pulumi.Input[str] tailloss_probe: Enabling this setting allows TCP to send a probe segment to trigger fast recovery instead of recovering a loss via a retransmission timeout,By default, this setting is enabled.
        :param pulumi.Input[str] timewait_recycle: Using this setting enabled, the system can recycle a wait-state connection immediately upon receipt of a new connection request instead of having to wait until the connection times out of the wait state. By default, this setting is enabled.
        :param pulumi.Input[str] verified_accept: Specifies, when checked (enabled), that the system can actually communicate with the server before establishing a client connection. To determine this, the system sends the server a SYN packet before responding to the client's SYN with a SYN-ACK. When unchecked, the system accepts the client connection before selecting a server to talk to. By default, this setting is `disabled`.
        :param pulumi.Input[int] zerowindow_timeout: Specifies the timeout in milliseconds for terminating a connection with an effective zero length TCP transmit window.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProfileTcpState.__new__(_ProfileTcpState)

        __props__.__dict__["close_wait_timeout"] = close_wait_timeout
        __props__.__dict__["congestion_control"] = congestion_control
        __props__.__dict__["defaults_from"] = defaults_from
        __props__.__dict__["deferred_accept"] = deferred_accept
        __props__.__dict__["delayed_acks"] = delayed_acks
        __props__.__dict__["early_retransmit"] = early_retransmit
        __props__.__dict__["fast_open"] = fast_open
        __props__.__dict__["finwait2timeout"] = finwait2timeout
        __props__.__dict__["finwait_timeout"] = finwait_timeout
        __props__.__dict__["idle_timeout"] = idle_timeout
        __props__.__dict__["initial_congestion_windowsize"] = initial_congestion_windowsize
        __props__.__dict__["keepalive_interval"] = keepalive_interval
        __props__.__dict__["nagle"] = nagle
        __props__.__dict__["name"] = name
        __props__.__dict__["partition"] = partition
        __props__.__dict__["proxybuffer_high"] = proxybuffer_high
        __props__.__dict__["receive_windowsize"] = receive_windowsize
        __props__.__dict__["send_buffersize"] = send_buffersize
        __props__.__dict__["tailloss_probe"] = tailloss_probe
        __props__.__dict__["timewait_recycle"] = timewait_recycle
        __props__.__dict__["verified_accept"] = verified_accept
        __props__.__dict__["zerowindow_timeout"] = zerowindow_timeout
        return ProfileTcp(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="closeWaitTimeout")
    def close_wait_timeout(self) -> pulumi.Output[int]:
        """
        Specifies the number of seconds that a connection remains in a LAST-ACK state before quitting. A value of 0 represents a term of forever (or until the maxrtx of the FIN state). The default value is 5 seconds.
        """
        return pulumi.get(self, "close_wait_timeout")

    @property
    @pulumi.getter(name="congestionControl")
    def congestion_control(self) -> pulumi.Output[Optional[str]]:
        """
        Specifies the algorithm to use to share network resources among competing users to reduce congestion. The default is High Speed.
        """
        return pulumi.get(self, "congestion_control")

    @property
    @pulumi.getter(name="defaultsFrom")
    def defaults_from(self) -> pulumi.Output[str]:
        """
        Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        """
        return pulumi.get(self, "defaults_from")

    @property
    @pulumi.getter(name="deferredAccept")
    def deferred_accept(self) -> pulumi.Output[str]:
        """
        Specifies, when enabled, that the system defers allocation of the connection chain context until the client response is received. This option is useful for dealing with 3-way handshake DOS attacks. The default value is disabled.
        """
        return pulumi.get(self, "deferred_accept")

    @property
    @pulumi.getter(name="delayedAcks")
    def delayed_acks(self) -> pulumi.Output[Optional[str]]:
        """
        Specifies, when checked (enabled), that the system can send fewer than one ACK (acknowledgment) segment per data segment received. By default, this setting is enabled.
        """
        return pulumi.get(self, "delayed_acks")

    @property
    @pulumi.getter(name="earlyRetransmit")
    def early_retransmit(self) -> pulumi.Output[Optional[str]]:
        """
        Enabling this setting allows TCP to assume a packet is lost after fewer than the standard number of duplicate ACKs, if there is no way to send new data and generate more duplicate ACKs.
        """
        return pulumi.get(self, "early_retransmit")

    @property
    @pulumi.getter(name="fastOpen")
    def fast_open(self) -> pulumi.Output[str]:
        """
        When enabled, permits TCP Fast Open, allowing properly equipped TCP clients to send data with the SYN packet. Default is `enabled`. If `fast_open` set to `enabled`, argument `verified_accept` can't be set to `enabled`.
        """
        return pulumi.get(self, "fast_open")

    @property
    @pulumi.getter
    def finwait2timeout(self) -> pulumi.Output[int]:
        """
        Specifies the number of seconds that a connection is in the FIN-WAIT-2 state before quitting. The default value is 300 seconds. A value of 0 (zero) represents a term of forever (or until the maxrtx of the FIN state).
        """
        return pulumi.get(self, "finwait2timeout")

    @property
    @pulumi.getter(name="finwaitTimeout")
    def finwait_timeout(self) -> pulumi.Output[int]:
        """
        Specifies the number of seconds that a connection is in the FIN-WAIT-1 or closing state before quitting. The default value is 5 seconds. A value of 0 (zero) represents a term of forever (or until the maxrtx of the FIN state). You can also specify immediate or indefinite.
        """
        return pulumi.get(self, "finwait_timeout")

    @property
    @pulumi.getter(name="idleTimeout")
    def idle_timeout(self) -> pulumi.Output[int]:
        """
        Specifies the number of seconds that a connection is idle before the connection is eligible for deletion. The default value is 300 seconds.
        """
        return pulumi.get(self, "idle_timeout")

    @property
    @pulumi.getter(name="initialCongestionWindowsize")
    def initial_congestion_windowsize(self) -> pulumi.Output[Optional[int]]:
        """
        Specifies the initial congestion window size for connections to this destination. Actual window size is this value multiplied by the MSS (Maximum Segment Size) for the same connection. The default is 10. Valid values range from 0 to 64.
        """
        return pulumi.get(self, "initial_congestion_windowsize")

    @property
    @pulumi.getter(name="keepaliveInterval")
    def keepalive_interval(self) -> pulumi.Output[int]:
        """
        Specifies the keep alive probe interval, in seconds. The default value is 1800 seconds.
        """
        return pulumi.get(self, "keepalive_interval")

    @property
    @pulumi.getter
    def nagle(self) -> pulumi.Output[Optional[str]]:
        """
        Specifies whether the system applies Nagle's algorithm to reduce the number of short segments on the network.If you select Auto, the system determines whether to use Nagle's algorithm based on network conditions. By default, this setting is disabled.
        """
        return pulumi.get(self, "nagle")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of the LTM TCP Profile,name should be `full path`. The full path is the combination of the `partition + name` (example: /Common/my-pool ) or  `partition + directory + name` of the resource  (example: /Common/test/my-pool )
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def partition(self) -> pulumi.Output[Optional[str]]:
        """
        name of partition
        """
        return pulumi.get(self, "partition")

    @property
    @pulumi.getter(name="proxybufferHigh")
    def proxybuffer_high(self) -> pulumi.Output[Optional[int]]:
        """
        Specifies the proxy buffer level, in bytes, at which the receive window is closed.
        """
        return pulumi.get(self, "proxybuffer_high")

    @property
    @pulumi.getter(name="receiveWindowsize")
    def receive_windowsize(self) -> pulumi.Output[Optional[int]]:
        """
        Specifies the maximum advertised RECEIVE window size. This value represents the maximum number of bytes to which the RECEIVE window can scale. The default is 65535 bytes.
        """
        return pulumi.get(self, "receive_windowsize")

    @property
    @pulumi.getter(name="sendBuffersize")
    def send_buffersize(self) -> pulumi.Output[Optional[int]]:
        """
        Specifies the SEND window size. The default is 131072 bytes.
        """
        return pulumi.get(self, "send_buffersize")

    @property
    @pulumi.getter(name="taillossProbe")
    def tailloss_probe(self) -> pulumi.Output[Optional[str]]:
        """
        Enabling this setting allows TCP to send a probe segment to trigger fast recovery instead of recovering a loss via a retransmission timeout,By default, this setting is enabled.
        """
        return pulumi.get(self, "tailloss_probe")

    @property
    @pulumi.getter(name="timewaitRecycle")
    def timewait_recycle(self) -> pulumi.Output[Optional[str]]:
        """
        Using this setting enabled, the system can recycle a wait-state connection immediately upon receipt of a new connection request instead of having to wait until the connection times out of the wait state. By default, this setting is enabled.
        """
        return pulumi.get(self, "timewait_recycle")

    @property
    @pulumi.getter(name="verifiedAccept")
    def verified_accept(self) -> pulumi.Output[Optional[str]]:
        """
        Specifies, when checked (enabled), that the system can actually communicate with the server before establishing a client connection. To determine this, the system sends the server a SYN packet before responding to the client's SYN with a SYN-ACK. When unchecked, the system accepts the client connection before selecting a server to talk to. By default, this setting is `disabled`.
        """
        return pulumi.get(self, "verified_accept")

    @property
    @pulumi.getter(name="zerowindowTimeout")
    def zerowindow_timeout(self) -> pulumi.Output[Optional[int]]:
        """
        Specifies the timeout in milliseconds for terminating a connection with an effective zero length TCP transmit window.
        """
        return pulumi.get(self, "zerowindow_timeout")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['IRuleArgs', 'IRule']

@pulumi.input_type
class IRuleArgs:
    def __init__(__self__, *,
                 irule: pulumi.Input[str],
                 name: pulumi.Input[str]):
        """
        The set of arguments for constructing a IRule resource.
        :param pulumi.Input[str] irule: Body of the iRule
        :param pulumi.Input[str] name: Name of the iRule
        """
        pulumi.set(__self__, "irule", irule)
        pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def irule(self) -> pulumi.Input[str]:
        """
        Body of the iRule
        """
        return pulumi.get(self, "irule")

    @irule.setter
    def irule(self, value: pulumi.Input[str]):
        pulumi.set(self, "irule", value)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        """
        Name of the iRule
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _IRuleState:
    def __init__(__self__, *,
                 irule: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering IRule resources.
        :param pulumi.Input[str] irule: Body of the iRule
        :param pulumi.Input[str] name: Name of the iRule
        """
        if irule is not None:
            pulumi.set(__self__, "irule", irule)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def irule(self) -> Optional[pulumi.Input[str]]:
        """
        Body of the iRule
        """
        return pulumi.get(self, "irule")

    @irule.setter
    def irule(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "irule", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the iRule
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


class IRule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 irule: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        `ltm.IRule` Creates iRule on BIG-IP F5 device

        For resources should be named with their "full path". The full path is the combination of the partition + name of the resource. For example /Common/my-pool.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip
        import pulumi_std as std

        # Loading from a file is the preferred method
        rule = f5bigip.ltm.IRule("rule",
            name="/Common/terraform_irule",
            irule=std.file(input="myirule.tcl").result)
        rule2 = f5bigip.ltm.IRule("rule2",
            name="/Common/terraform_irule2",
            irule=\"\"\"when CLIENT_ACCEPTED {
             log local0. "test"
           }
        \"\"\")
        ```

        ##myirule.tcl

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] irule: Body of the iRule
        :param pulumi.Input[str] name: Name of the iRule
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: IRuleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        `ltm.IRule` Creates iRule on BIG-IP F5 device

        For resources should be named with their "full path". The full path is the combination of the partition + name of the resource. For example /Common/my-pool.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip
        import pulumi_std as std

        # Loading from a file is the preferred method
        rule = f5bigip.ltm.IRule("rule",
            name="/Common/terraform_irule",
            irule=std.file(input="myirule.tcl").result)
        rule2 = f5bigip.ltm.IRule("rule2",
            name="/Common/terraform_irule2",
            irule=\"\"\"when CLIENT_ACCEPTED {
             log local0. "test"
           }
        \"\"\")
        ```

        ##myirule.tcl

        :param str resource_name: The name of the resource.
        :param IRuleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(IRuleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 irule: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = IRuleArgs.__new__(IRuleArgs)

            if irule is None and not opts.urn:
                raise TypeError("Missing required property 'irule'")
            __props__.__dict__["irule"] = irule
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
        super(IRule, __self__).__init__(
            'f5bigip:ltm/iRule:IRule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            irule: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None) -> 'IRule':
        """
        Get an existing IRule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] irule: Body of the iRule
        :param pulumi.Input[str] name: Name of the iRule
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _IRuleState.__new__(_IRuleState)

        __props__.__dict__["irule"] = irule
        __props__.__dict__["name"] = name
        return IRule(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def irule(self) -> pulumi.Output[str]:
        """
        Body of the iRule
        """
        return pulumi.get(self, "irule")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of the iRule
        """
        return pulumi.get(self, "name")

